{% extends "base/base.html" %}
{% load static %}
{% block content %}
<div class="container" style="padding-top:100px">
    <div class="row">
        <div class="col-md-12">
            <div class="card">
                <div class="card-body card-header">
                   <img src="{% static 'img/logo_square.png' %}" id="square_logo">
                   <form action="{% url 'users:notebook_login' %}" method="POST">
                       {% csrf_token %}
                       <div class="form-group">{% for messages in messages %}{{ message }}{% endfor %}
                          <h3 style="font-variant: all-petite-caps;">Welcome to Snakeface!</h3>
                          <input {% if form.token.value %}value="{{ form.token.value }}"{% endif %} name="token" class="form-control" placeholder="Enter your token here" required id="id_token">
                          <small>The notebook token should be printed in the console where you ran the application.</small>
                       </div>
                       <input type="submit" value="Submit" class="btn btn-sm btn-primary">
                   </form>
               </div>
            </div>
        </div>
    </div>
</div>
{% endblock %}
{% block scripts %}
{% endblock %}
