         {% if favorites %}
         <div class="row">
            <div class="col-md-12">
                <h3 class="title">Favorites</h3>
                <p>These are {{ profile.username }}'s favorite collections on Singularity Hub.</p>
            </div>
        </div>

        <div class="row">
            <div class="col-md-12" class="table card material-table mdl-data-table--selectable">
                <table class="table">
                <thead>
                <tr>
                    <th>Name</th>
                    <th>Builds</th>
                    <th>Description</th>
                    <th>Stars <i class="fa fa-star"style="color:gold"></i></th>
                    <th>Downloads</th>
                    <th>Last Modified</th>
                </tr>
            </thead>
            <tbody>
                {% for f in favorites %}
                <tr>
                   <td><a href="{% url 'collection_details' f.collection.id %}">{{ f.collection.repo.full_name }}</a></td>
                   <td>{{ f.collection.containers.count }}</td>
                   <td>{% if f.collection.repo.description %}{{ f.collection.repo.description }}{% endif %}</td>
                   <td>{% if f.collection.star__count %}{{ f.collection.star__count }}{% else %}0{% endif %}</td>
                   <td>{% if f.collection.number_downloads %}{{ f.collection.number_downloads }}{% else %}0{% endif %}</td>
                   <td>{{ f.collection.modify_date|date:"Y-m-d"}}
                        {% if f.collection.repo.url %}
                        <a style="margin-right:20px;float:right" 
                           href="https://www.github.com/{{ f.collection.repo.full_name }}" target="_blank">
                     <i class="fa fa-github"></i></a>{% endif %}
                   </td>
                </tr>
                {% endfor %}
                </tbody>
                </table>
            </div>
        </div>
        {% else %} 
         <div class="row">
            <div class="col-md-12">
                <h4 class="title">Favorites</h4>
                <p>{{ profile.username }} doesn't have any favorite collections.</p>
            </div>
        </div>
        {% endif %}
