{% load static %}
        <footer class="footer-2">
            <div class="container">
                <div class="row">
                    <div class="col-xs-12">
                        <div class="footer-lower">
                            <div class="row">
                                <div class="col-xs-6">
                                    <span class="copyright">© Copyright 2020-2021 <a href="https://koesterlab.github.io">Snakemake Community</a>. All rights reserved<br/>.</span>
                                </div>
                                <div class="col-xs-6">
                                    <ul>
                                        <li style="float:right;" ><a href="https://github.com/snakemake/snakeface"><i class="icon ti ti-github"></i></a></li>
                                        <li style="float:right; padding-left:30px" ><a href="https://twitter.com/johanneskoester"><i class="icon ti ti-twitter-alt"></i></a></li>
                                    </ul>
                                </div>
                            </div>
                        </div>
                    </div>
                </div>
            </div>
        </footer>
