html * {
	font-family: 'Montserrat', sans-serif;
	box-sizing: border-box;
}

.login-box {
  background: #fff;
  padding: 20px;
  max-width: 480px;
  margin: 25vh auto;
  text-align: center;
  letter-spacing: 1px;
  position: relative;
}

.login-box h2 {
  margin: 20px 0 20px;
  padding: 0;
  text-transform: uppercase;
  color: #4688F1;
}

.social-button {
    background-position: 25px 0px;
    box-sizing: border-box;
    cursor: pointer;
    display: inline-block;
    height: 50px;
    line-height: 50px;
    text-align: left;
    text-decoration: none;
    text-transform: uppercase;
    vertical-align: middle;
    width: 100%;
	border-radius: 3px;
    margin: 10px auto;
    outline: rgb(255, 255, 255) none 0px;
    padding-left: 20%;
    transition: all 0.2s cubic-bezier(0.72, 0.01, 0.56, 1) 0s;
	-webkit-transition: all .3s ease;
    -moz-transition: all .3s ease;
    -ms-transition: all .3s ease;
    -o-transition: all .3s ease;
    transition: all .3s ease;
}

/* Google */


#google-connect {
    color: #DC4A3D;
    background: rgb(255, 255, 255) url('/static/img/social-buttons/google-plus.png') no-repeat scroll 5px 0px / 50px 50px padding-box border-box;
    border: 1px solid rgb(220, 74, 61);
}

#google-connect:hover {
    color: white;
    border-color: rgb(220, 74, 61);
    background: rgb(220, 74, 61) url('/static/img/social-buttons/google-plus-white.png') no-repeat scroll 5px 0px / 50px 50px padding-box border-box;
    -webkit-transition: all .8s ease-out;
    -moz-transition: all .3s ease;
    -ms-transition: all .3s ease;
    -o-transition: all .3s ease;
    transition: all .3s ease-out;
}

#google-connect span {
    box-sizing: border-box;
    color: rgb(220, 74, 61);
    cursor: pointer;
    text-align: center;
    text-transform: uppercase;
    border: 0px none rgb(220, 74, 61);
    outline: rgb(255, 255, 255) none 0px;
	-webkit-transition: all .3s ease;
    -moz-transition: all .3s ease;
    -ms-transition: all .3s ease;
    -o-transition: all .3s ease;
    transition: all .3s ease;
}

#google-connect:hover span {
    color:#FFF;
    -webkit-transition: all .3s ease;
    -moz-transition: all .3s ease;
    -ms-transition: all .3s ease;
    -o-transition: all .3s ease;
    transition: all .3s ease;
}

/* Twitter */


#twitter-connect {
    background: rgb(255, 255, 255) url('/static/img/social-buttons/twitter.png') no-repeat scroll 5px 1px / 45px 45px padding-box border-box;
    border: 1px solid rgb(85, 172, 238);
    color: #55ACEE;
}

#twitter-connect:hover {
    color: white;
    border-color: rgb(85, 172, 238);
    background: rgb(85, 172, 238) url('/static/img/social-buttons/twitter-white.png') no-repeat scroll 5px 1px / 45px 45px padding-box border-box;
    -webkit-transition: all .8s ease-out;
    -moz-transition: all .3s ease;
    -ms-transition: all .3s ease;
    -o-transition: all .3s ease;
    transition: all .3s ease-out;
}

#twitter-connect span {
    box-sizing: border-box;
    color: rgb(85, 172, 238);
    cursor: pointer;
    text-align: center;
    text-transform: uppercase;
    border: 0px none rgb(220, 74, 61);
    outline: rgb(255, 255, 255) none 0px;
	-webkit-transition: all .3s ease;
    -moz-transition: all .3s ease;
    -ms-transition: all .3s ease;
    -o-transition: all .3s ease;
    transition: all .3s ease;
}

#twitter-connect:hover span {
    color: #FFF;
    -webkit-transition: all .3s ease;
    -moz-transition: all .3s ease;
    -ms-transition: all .3s ease;
    -o-transition: all .3s ease;
    transition: all .3s ease;
}

/* Github */


#github-connect {
    color: black;
    background: rgb(255, 255, 255) url('/static/img/social-buttons/github.png') no-repeat scroll 13px 10px / 28px 28px padding-box border-box;
    border: 1px solid black;
}

#github-connect:hover {
    color: white;
    border-color: rgb(0, 119, 181);
    background: black url('/static/img/social-buttons/github-white.png') no-repeat scroll 13px 10px / 28px 28px padding-box border-box;
    -webkit-transition: all .8s ease-out;
    -moz-transition: all .3s ease;
    -ms-transition: all .3s ease;
    -o-transition: all .3s ease;
    transition: all .3s ease-out;
}

#github-connect span {
	box-sizing: border-box;
    color: rgb(0, 119, 181);
    cursor: pointer;
    text-align: center;
    text-transform: uppercase;
    border: 0px none rgb(0, 119, 181);
    outline: rgb(255, 255, 255) none 0px;
	-webkit-transition: all .3s ease;
    -moz-transition: all .3s ease;
    -ms-transition: all .3s ease;
    -o-transition: all .3s ease;
    transition: all .3s ease;
}

#github-connect:hover span {
    color: #FFF;
    -webkit-transition: all .3s ease;
    -moz-transition: all .3s ease;
    -ms-transition: all .3s ease;
    -o-transition: all .3s ease;
    transition: all .3s ease;
}

/* Gitlab */

#gitlab-connect {
    color: black;
    background: rgb(255, 255, 255) url('/static/img/social-buttons/gitlab.png') no-repeat scroll 13px 10px / 28px 28px padding-box border-box;
    border: 1px solid black;
}

#gitlab-connect:hover {
    color: white;
    border-color: rgb(0, 119, 181);
    background: black url('/static/img/social-buttons/gitlab.png') no-repeat scroll 13px 10px / 28px 28px padding-box border-box;
    -webkit-transition: all .8s ease-out;
    -moz-transition: all .3s ease;
    -ms-transition: all .3s ease;
    -o-transition: all .3s ease;
    transition: all .3s ease-out;
}

#gitlab-connect span {
	box-sizing: border-box;
    color: rgb(0, 119, 181);
    cursor: pointer;
    text-align: center;
    text-transform: uppercase;
    border: 0px none rgb(0, 119, 181);
    outline: rgb(255, 255, 255) none 0px;
	-webkit-transition: all .3s ease;
    -moz-transition: all .3s ease;
    -ms-transition: all .3s ease;
    -o-transition: all .3s ease;
    transition: all .3s ease;
}

#gitlab-connect:hover span {
    color: #FFF;
    -webkit-transition: all .3s ease;
    -moz-transition: all .3s ease;
    -ms-transition: all .3s ease;
    -o-transition: all .3s ease;
    transition: all .3s ease;
}


/* BitBucket */

#bitbucket-connect {
    color: black;
    background: rgb(255, 255, 255) url('/static/img/social-buttons/bitbucket.png') no-repeat scroll 13px 10px / 28px 28px padding-box border-box;
    border: 1px solid black;
}

#bitbucket-connect:hover {
    color: white;
    border-color: rgb(0, 119, 181);
    background: black url('/static/img/social-buttons/bitbucket.png') no-repeat scroll 13px 10px / 28px 28px padding-box border-box;
    -webkit-transition: all .8s ease-out;
    -moz-transition: all .3s ease;
    -ms-transition: all .3s ease;
    -o-transition: all .3s ease;
    transition: all .3s ease-out;
}

#bitbucket-connect span {
	box-sizing: border-box;
    color: rgb(0, 119, 181);
    cursor: pointer;
    text-align: center;
    text-transform: uppercase;
    border: 0px none rgb(0, 119, 181);
    outline: rgb(255, 255, 255) none 0px;
	-webkit-transition: all .3s ease;
    -moz-transition: all .3s ease;
    -ms-transition: all .3s ease;
    -o-transition: all .3s ease;
    transition: all .3s ease;
}

#bitbucket-connect:hover span {
    color: #FFF;
    -webkit-transition: all .3s ease;
    -moz-transition: all .3s ease;
    -ms-transition: all .3s ease;
    -o-transition: all .3s ease;
    transition: all .3s ease;
}

