<div class="row">
    <div class="col-md-12" style="padding-top:20px;float:right">
    <a class="social-icon" href="https://twitter.com/intent/tweet?text=Singularity Container {{ collection.name }}&url={{ domain }}/collections/{{ collection.id }}&via=SingularityApp&related=SingularityApp" rel="nofollow" target="_blank" title="Share on Twitter"><i class="fa fa-2x fa-twitter"></i></a>
    <a class="social-icon"  href="https://facebook.com/sharer.php?u={{ domain }}/collections/{{ collection.id }}" rel="nofollow" target="_blank" title="Share on Facebook"><i class="fa fa-2x fa-facebook"></i></a>
    <a class="social-icon"  href="http://www.reddit.com/submit?url={{ domain }}/collections/{{ collection.id }}&title=Singularity Container {{ collection.name }}" rel="nofollow" target="_blank" title="Share on Reddit"><i class="fa fa-2x fa-reddit"></i></a>
    </div>
</div>
