<div class="row">
    <div class="col-md-12">

        <h3>{{ profile.username }}</h3>

        <p>The following counts pertain to collections owned by {% if user == profile %}you{% else %}{{ profile.username }}{% endif %}</p>
        <ul class="list-group">
            <li class="list-group-item">
                <span class="badge">{{ stars }}</span>
                    Starred Collections
            </li>
            <li class="list-group-item">
                <span class="badge">{% if downloads %}{{ downloads }}{% else %}0{% endif %}</span>
                    Collection Downloads
            </li>
        </ul>       
        <hr>
    </div>
</div>
