{% extends "base/page.html" %}
{% load crispy_forms_tags %}
{% load my_filters %}
{% load static %}
{% block content %}
<div class="row">
    <div class="col">
        <div class="card">
           <div class="card-body">
               <form method="POST" action="{% url 'main:new_collection' %}">
                 {% csrf_token %}
                 {{ form | crispy }}
                 <input class="btn btn-sm btn-primary" role="button" type="submit" value="Create"/> 
               </form>
           </div>
        </div>
    </div>
</div>
{% endblock %}
{% block scripts %}
<script>
$(document).ready(function(){
     $("input[type=checkbox]").bootstrapSwitch();
});
</script>
{% endblock %}
