<hr>
<div class="row">
    <div class="col-md-12">
        <h4>Delete Account</h4>
        <p>This will delete all of your container collections, and your user account.
           This action cannot be undone.</p>
        <a style="text-transform:none"
               id="delete_account"
               title="Delete account and all associated container collections.">
               <button class="btn btn-danger">Delete Account</button></a>
    </div>
</div>
