{% if messages %}<div class="row">
    <div class="col-md-12">
      {% for message in messages %}
        <div class="alert alert-{% if message.tags == 'info' %}primary{% else %}{{ message.tags }}{% endif %}" role="alert">
          <button type="button" aria-hidden="true" class="close" data-dismiss="alert">
             <i class="nc-icon nc-simple-remove"></i>
          </button>
          <span>{{ message }}</span>
        </div>
        {% endfor %}
    </div>
</div>{% endif %}
