{% load static %}
<!DOCTYPE HTML>
<html lang="en">
    <head>

        <!--[if lt IE 7]>      <html class="no-js lt-ie9 lt-ie8 lt-ie7"> <![endif]-->
        <!--[if IE 7]>         <html class="no-js lt-ie9 lt-ie8"> <![endif]-->
        <!--[if IE 8]>         <html class="no-js lt-ie9"> <![endif]-->
        <!--[if gt IE 8]><!--> <html class="no-js"> <!--<![endif]-->
        <meta charset="utf-8">
        <meta name="viewport" content="width=device-width, initial-scale=1, shrink-to-fit=no">
        <meta http-equiv="X-UA-Compatible" content="IE=edge">
        <title>{% block title %}Snakeface: Snakemake Interface{% endblock %}</title>
        <meta name="description" content="snakeface" />
        <meta name="keywords" content="workflows,snakemake,pipelines,hpc,cloud" />
        <meta name="author" content="vsoch" />
        <link rel="icon" type="image/ico" href="/static/img/favicon.ico"/>

        <!-- Facebook and Twitter integration -->
        <meta property="og:title" content="Snakeface"/>
        <meta property="og:image" content="{% static 'images/logo-temporary.png' %}"/>
        <meta property="og:url" content="{{ DOMAIN }}"/>
        <meta property="og:site_name" content="Snakeface"/>

        <meta property="og:description" content="Snakeface"/>
        <meta name="twitter:title" content="Snakeface" />
        <meta name="twitter:image" content="{% static 'images/logo-temporary.png' %}" />
        {% if TWITTER_USERNAME %}<meta name="twitter:url" content="https://www.twitter.com/{{ TWITTER_USERNAME }}" />{% endif %}
        <meta name="twitter:card" content="summary" />

        {% include "base/ga.html" %}

        <link href="https://fonts.googleapis.com/css?family=Montserrat:400,700,200" rel="stylesheet" />
        <link href="{% static 'css/font-awesome.min.css' %}" rel="stylesheet" type="text/css" media="all">
        <link href="{% static 'css/bootstrap.min.css' %}" rel="stylesheet" />
        <link href="{% static 'css/demo.css' %}" rel="stylesheet" />
        <link href="{% static 'css/themify-icons.css' %}" rel="stylesheet" type="text/css" media="all" />
        <link href="{% static 'css/light-bootstrap-dashboard.css' %}" rel="stylesheet" />
        <link href="{% static 'css/custom.css' %}" rel="stylesheet" type="text/css" media="all" />
        <link rel="stylesheet" href="https://cdn.datatables.net/1.10.22/css/jquery.dataTables.min.css" type="text/css">
        <link rel="stylesheet" href="https://cdn.datatables.net/1.10.23/css/dataTables.bootstrap4.min.css" type="text/css">
        
        {% block fonts %}{% endblock %}
        {% block css %}{% endblock %}
        {% block head %}{% endblock %}
    </head>

    {% block body %}
    <body>
    {% include "base/loader.html" %}
    {% block container %}{% block content %}{% endblock %}{% endblock %}
    <div id="line"></div>
    {% if include_footer %}{% include "base/footer.html" %}{% endif %}

    <script src="{% static 'js/jquery-3.5.1.min.js' %}"></script>
    <script src="{% static 'js/ScrollToPlugin.min.js' %}"></script>
    <script src="{% static 'js/popper.min.js' %}"></script>
    <script src="{% static 'js/tether.min.js' %}"></script>
    <script src="{% static 'js/bootstrap.min.js' %}"></script>
    <script src="{% static 'js/bootstrap-switch.js' %}"></script>
    <script src="{% static 'js/flexslider.min.js' %}"></script>
    <script src="https://cdn.datatables.net/1.10.23/js/jquery.dataTables.min.js"></script>
    <script src="https://cdn.datatables.net/1.10.23/js/dataTables.bootstrap4.min.js"></script>

    {% block scripts %}{% endblock %}
    </body>
    {% endblock %}

</html>
