/*!
// Contents
// ------------------------------------------------

 1. Mixins
 2. Helper classes & resets
 3. Colours
 4. Typography
 5. Buttons
 6. Navigation
 7. Headers, sliders, dividers
 8. Short strip sections
 9. Text-based sections
 10. Team
 11. Portfolio & Galleries
 12. Pricing
 13. Social
 14. Blog
 15. Shop
 16. Contact
 17. Form Elements
 18. Footers
 19. Utility Pages
/*!
// 1. Mixins
// --------------------------------------------------*/
.vertical-align {
  position: relative;
  top: 50%;
  -webkit-transform: translateY(-50%);
  -ms-transform: translateY(-50%);
  transform: translateY(-50%);
}
.preserve3d {
  -webkit-transform-style: preserve-3d;
  -moz-transform-style: preserve-3d;
  transform-style: preserve-3d;
}
.disable-select {
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.overlay:before {
  content: '';
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 1;
  background: #333333;
  opacity: 0.3;
}
.overlay-primary:before {
  content: '';
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 1;
  background: #33c68a;
  opacity: 0.9;
}
.overlay .container {
  position: relative;
  z-index: 2;
}
.overlay-light-gradient:before {
  content: '';
  position: absolute;
  top: 0;
  left: 0;
  width: 100%;
  height: 100%;
  z-index: 1;
  background: #ffffff;
  opacity: 1;
  background: linear-gradient(to right, #ffffff 10%, rgba(125, 185, 232, 0) 100%);
  /* W3C */
}
/*!
// 2. Global & Helper Classes
// --------------------------------------------------*/
body {
  background: #eee;
  font-family: 'Roboto', "Helvetica Neue", Helvetica, Arial, sans-serif;
  -moz-osx-font-smoothing: grayscale;
  -webkit-font-smoothing: antialiased;
  color: #333;
  font-size: 16px;
  line-height: 24px;
}
.main-container,
.footer-container {
  max-width: 1580px;
  margin: 0px auto;
/*  position: relative;*/
  z-index: 1;
}
.main-container {
  clear: both;
}

section:first-of-type {
   padding-top: 0px !important;
}
section {
  background: #f7f7f7;
  padding:  0;
  position: relative;
  overflow: hidden;
}
section:nth-of-type(even) {
  background: #fff;
}
section.fullwidth div[class*='col-'] {
  padding: 0;
}
section.double-pad {
  padding: 160px 0;
}
section.large-pad {
  padding: 120px 0;
}
.no-pad {
  padding: 0;
}
.detail-line {
  width: 30px;
  height: 1px;
  background: #333333;
  margin-bottom: 24px;
}
ul {
  list-style: none;
  margin: 0;
  padding: 0;
}
a {
  text-decoration: none;
}
a:hover {
  text-decoration: none;
}
div[class*='col-'] div[class*='col-'] {
  padding-left: 0;
}
img {
  max-width: 100%;
}
.duplicatable-content {
  padding: 80px 0 40px 0;
}
.duplicatable-content div[class*='col-'] {
  margin-bottom: 40px;
}
@media all and (max-width: 767px) {
  br {
    display: none;
  }
}
body.boxed .main-container,
body.boxed .footer-container,
body.boxed nav {
  max-width: 1280px;
}
/*!
// 3. Colors
// --------------------------------------------------*/
.color-love {
  color: #e21a1a !important;
}
.text-white {
  color: #fff !important;
}
.dark-bg {
  background-color: #222 !important;
}
/*!
// 4. Typography
// --------------------------------------------------*/
p {
  font-size: 16px;
  line-height: 24px;
  font-weight: 400;
  margin-bottom: 24px;
}
p.lead {
  font-size: 16px;
  line-height: 26px;
  font-weight: 400;
}
p:last-child {
  margin-bottom: 0px;
}
p.super-lead {
  font-size: 24px;
  font-weight: 300;
  line-height: 36px;
  color: #333333;
}
p strong {
  font-weight: 500;
}
@media all and (max-width: 767px) {
  p.super-lead {
    font-size: 18px;
    line-height: 28px;
  }
}
@media all and (max-width: 768px) {
  p.super-lead br {
    display: none;
  }
}
span.title {
  font-size: 18px;
  font-weight: 400;
  display: inline-block;
  margin-bottom: 8px;
}
span.sub {
  font-size: 16px;
}
h1,
h2,
h3,
h4,
h5,
h6 {
  color: #333333;
  margin-top: 0px;
}
h1 {
  font-size: 48px;
  line-height: 56px;
  font-weight: 700;
  margin-bottom: 32px;
  font-weight: 300;
}
h2 {
  font-weight: 300;
  font-size: 32px;
  line-height: 40px;
  margin-bottom: 32px;
}
h3 {
  font-weight: 300;
  font-size: 28px;
  line-height: 34px;
  margin-bottom: 24px;
  color: #33c68a;
}
h4 {
  font-weight: 300;
  font-size: 24px;
  line-height: 32px;
  margin-bottom: 24px;
}
h5 {
  font-size: 18px;
  font-weight: normal;
  margin-bottom: 24px;
  line-height: 28px;
}
@media all and (max-width: 767px) {
  h1 {
    font-size: 28px;
    line-height: 36px;
    margin-bottom: 24px;
    max-width: 100%;
  }
  h2 {
    font-size: 20px;
    line-height: 28px;
    margin-bottom: 24px;
  }
  h3 {
    font-size: 20px;
    line-height: 28px;
    margin-bottom: 24px;
  }
  h4 {
    font-size: 18px;
    line-height: 26px;
  }
}
.alt-font {
  font-family: 'Montserrat', "Helvetica Neue", Helvetica, Arial, sans-serif;
  text-transform: uppercase;
  font-weight: bold;
}
.contrast-h1 {
  color: #bbb !important;
}
.contrast-h1 strong {
  color: #333333 !important;
  font-weight: 300;
}
/*!
// 5. Buttons
// --------------------------------------------------*/
a {
  color: #33c68a;
}
a,
a:hover,
a:visited,
a:active,
a:link,
a:active {
  text-decoration: none;
}
.btn {
  font-family: 'Montserrat', "Helvetica Neue", Helvetica, Arial, sans-serif;
  text-transform: uppercase;
  font-weight: bold;
  text-align: center;
  font-size: 12px;
  min-width: 170px;
  border: 3px solid;
  padding: 17px 0;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  border-radius: 0;
  border-color: #33c68a;
  color: #33c68a;
  cursor: pointer;
}
.btn-filled {
  background: #33c68a !important;
  color: #fff !important;
  border-color: #33c68a;
  font-weight: 600 !important;
  cursor: pointer;
}

.btn-filled:hover {
  background: #fff;
  color: #33c68a;
  border-color: #fff;
}
@media all and (max-width: 767px) {
  .btn {
    min-width: 0;
    padding: 10px 14px 12px 14px;
    border: 2px solid;
    cursor: pointer;
  }
  .btn-filled {
    border-color: #33c68a;
    margin:5px 0;
  }
}
.btn-white {
  border-color: #fff;
  color: #fff;
  margin:5px 0;
}
.btn-white:hover {
  background: #fff;
  color: #33c68a;
  border-color: #fff;
}
.btn-white.btn-filled {
  background: #fff;
  color: #33c68a;
}
.btn-white.btn-filled:hover {
  background: #33c68a;
  color: #fff;
  border-color: #33c68a;
}
.btn:nth-of-type(even) {
  /*margin-left: 24px;*/
}
@media all and (max-width: 767px) {
  .btn:nth-of-type(even) {
    margin-left: 0;
  }
}
.btn-sm {
  max-width: 120px;
  min-width: 0;
  padding: 8px 16px;
  border: 2px solid;
}
.btn-sm.btn-filled {
  border-color: #33c68a;
}
.btn-sm.btn-filled:hover {
  border-color: #fff;
}
.text-link {
  font-weight: 400;
  display: inline-block;
  border-bottom: 2px solid;
  text-decoration: none;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  position: relative;
  width: auto;
  color: #33c68a;
  border-color: #33c68a;
}
.text-link.text-white {
  border-color: #fff;
  color: #fff;
}
.text-link.text-white:hover {
  color: #fff;
  border-color: #fff;
}
.text-link .arrow_right {
  width: 17px;
  opacity: 0;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  transform: translate3d(30px, 0, 0);
  -webkit-transform: translate3d(30px, 0, 0);
  -moz-transform: translate3d(30px, 0, 0);
  display: inline-block;
  position: relative;
  position: absolute;
  right: 0;
  top: 5px;
  font-size: 15px;
}
.text-link:hover .arrow_right {
  opacity: 1;
  transform: translate3d(0, 0, 0);
  -webkit-transform: translate3d(0, 0, 0);
  -moz-transform: translate3d(0, 0, 0);
}
.text-link:hover {
  padding-right: 20px;
  color: #238960;
}
.inline-link {
  color: #33c68a;
  font-weight: 700;
}
.inline-linl:hover {
  color: #238960;
}
/*!
// 6. Navigation
// --------------------------------------------------*/
nav {
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.nav-fixed {
  position: fixed;
  top: 0;
  width: 100%;
  z-index: 99;
}
@media all and (max-width: 767px) {
  .nav-fixed {
    position: absolute;
  }
}
.menu {
  margin: 0;
  display: inline-block;
  float: left;
}
nav li {
  float: left;
  padding: 0;
}
.menu li:last-child {
  padding-right: 0;
}
.home-link {
  float: left;
}
.nav-1 {
  background: #333;
  background: rgba(30, 30, 30, 0.4);
  position: fixed;
  top: 0;
  width: 100%;
  z-index: 99;
  transition: all 0.7s ease;
  -webkit-transition: all 0.7s ease;
  -moz-transition: all 0.7s ease;
  max-width: 1580px;
  left: 0;
  right: 0;
  margin: 0 auto;
}
.nav-1:hover {
  background: rgba(30, 30, 30, 0.9);
}
.nav-1 .logo {
  max-height: 25px;
  max-width: 100%;
  margin-right: 64px;
  margin-top: 19px;
}
@media all and (max-width: 1200px) {
  .nav-1 .logo {
    margin-right: 32px;
  }
}
.nav-1 ul li a {
  font-family: 'Montserrat', "Helvetica Neue", Helvetica, Arial, sans-serif;
  text-transform: uppercase;
  font-weight: bold;
  color: #33c68a;
  display: inline-block;
  margin: 24px 0px 16px 0px;
  color: #fff;
  font-size: 11px;
  margin: 0;
  padding: 18px 24px;
  transition: all 0.2s ease;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
  opacity: 0.7;
}
.nav-1 ul li a:hover {
  opacity: 1;
}
.nav-1 ul li {
  border-right: 1px solid rgba(255, 255, 255, 0.1);
}
.nav-1 ul li:first-child {
  border-left: 1px solid rgba(255, 255, 255, 0.1);
}
.nav-1 .btn {
  padding: 8px 16px;
  max-width: 120px;
  min-width: 0;
  font-size: 11px;
  float: right;
  position: relative;
  top: 13px;
  opacity: 0.7;
  border: 2px solid;
}
.nav-1 .btn:hover {
  opacity: 1;
  border-color: #fff;
}
.nav-1 .btn:nth-of-type(even) {
  margin-left: 32px;
}
.nav-1.scrolled,
.nav-2.scrolled,
.nav-3.scrolled {
  background: rgba(30, 30, 30, 0.9);
}
@media all and (max-width: 1200px) {
  .nav-1 .btn {
    display: none;
  }
}
.nav-1 .social-links {
  float: right;
}
.nav-1 .social-links li {
  padding: 20px 0 12px 0;
  margin-right: 24px;
}
.nav-1 .social-links a,
.nav-2 .social-links a {
  color: #fff;
  font-size: 14px;
  transition: all 0.2s ease;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
  opacity: 0.4;
}
.nav-1 .social-links a:hover,
.nav-2 .social-links a:hover {
  opacity: 1;
}
.nav-1 ul {
  overflow: hidden;
}
.nav-1 ul li {
  margin-left: -1px;
}
.nav-1 ul:hover {
  overflow: visible;
}
.nav-1 ul > li:hover {
  border-left: 1px solid rgba(255, 255, 255, 0.1);
}
.nav-1 ul ul > li:hover {
  border-left: none;
}
.nav-1 ul ul {
  max-height: 0;
  transition: all 0.5s ease;
  -webkit-transition: all 0.5s ease;
  -moz-transition: all 0.5s ease;
  position: relative;
  overflow: visible;
  opacity: 0;
  max-width: 0;
}
.nav-1 ul ul li {
  float: none;
  border: none;
  padding: 0;
  position: relative;
}
.nav-1 ul ul li:first-child {
  padding: 0;
  border: none;
}
.nav-1 ul ul li a {
  padding: 4px 24px;
}
.nav-1 ul ul li:last-child a {
  padding-bottom: 12px;
}
.nav-1 ul li:hover > ul {
  max-height: 400px;
  opacity: 1;
  visibility: visible;
  max-width: 400px;
}
.nav-1 ul ul ul {
  position: absolute;
  left: 100%;
  top: -4px;
  opacity: 0;
  transition: all 0.5s ease;
  -webkit-transition: all 0.5s ease;
  -moz-transition: all 0.5s ease;
  background: rgba(35, 35, 35, 0.9);
  z-index: 999;
  overflow: hidden;
  padding: 4px 0 0 0;
  min-width: 150px;
  visibility: hidden;
  margin-left: -1px;
}
.nav-1 ul ul ul:hover {
  overflow: hidden;
}
.nav-1 ul ul ul li a {
  padding: 4px 16px;
}
.nav-light ul ul ul {
  background: rgba(255, 255, 255, 0.8);
}
.nav-light ul ul ul li a {
  color: #333333;
}
.nav-1 .social-links a {
  padding: 0;
}
.nav-1 .social-links li {
  border: none !important;
}
.nav-1 .social-links {
  margin-left: 24px;
}
@media all and (max-width: 1200px) {
  .nav-1 .social-links {
    display: none;
  }
}
.has-dropdown-2:before {
  content: "\e684";
  display: inline-block;
  font-family: 'Pe-icon-7-stroke';
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  color: #fff;
  position: absolute;
  font-size: 20px;
  top: 5px;
  right: 18px;
  cursor: default;
  display: none;
}
.has-dropdown:before {
  content: "\e688";
  display: inline-block;
  font-family: 'Pe-icon-7-stroke';
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  -moz-osx-font-smoothing: grayscale;
  color: #fff;
  float: right;
  position: relative;
  font-size: 20px;
  right: 18px;
  top: 20px;
}
.has-dropdown a {
  padding-right: 32px !important;
}
.nav-light .has-dropdown:before,
.nav-light .has-dropdown-2:before {
  color: #333333;
}
.nav-light i {
  color: #333333 !important;
}
@media all and (max-width: 1023px) {
  .nav-1 ul ul {
    position: relative;
    left: 16px;
  }
  .nav-1 ul ul ul {
    position: relative;
    left: 24px;
    background: none;
  }
  .has-dropdown:before {
    top: 5px;
  }
}
.mobile-toggle {
  position: absolute;
  right: 32px;
  top: 24px;
  cursor: pointer;
  display: none;
}
.bar-1,
.bar-2,
.bar-3 {
  width: 25px;
  height: 3px;
  background: #333;
  transition: all 0.2s ease;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
}
.bar-1,
.bar-2,
.bar-3 {
  background: #fff;
  transition: all 0.2s ease;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
}
.bar-2 {
  position: relative;
  margin-top: 8px;
}
.bar-3 {
  position: relative;
  top: 8px;
  opacity: 0;
}
.nav-1.nav-light {
  background: #fff;
  background: rgba(255, 255, 255, 0.9);
}
.nav-light .menu li a {
  color: #333333;
}
.nav-light .menu li,
.nav-light .menu li:first-child,
.nav-light .menu li:last-child {
  border-color: rgba(0, 0, 0, 0.1);
}
.nav-light .social-links a {
  color: #333333;
  opacity: 0.6;
}
.nav-light .bar-1,
.nav-light .bar-2 {
  background: #333333;
}
@media all and (max-width: 1023px) {
  .mobile-toggle {
    display: block;
  }
  .nav-1 {
    max-height: 60px;
    overflow: hidden;
    background: rgba(30, 30, 30, 0.9);
  }
  .nav-1 .social-links {
    display: none;
  }
  .nav-1 .logo {
    display: block;
    float: none;
  }
  .menu {
    width: 100%;
    margin-top: 24px;
  }
  .menu li {
    float: none;
    border: none !important;
    padding: 0;
    padding-left: 0 !important;
  }
  .menu li a {
    padding: 8px 0 8px 0 !important;
  }
  .subnav li {
    margin-left: 16px;
  }
  .open-menu {
    max-height: 900px;
  }
  .nav-1 .menu li:first-child {
    border-left: none;
  }
  .nav-1 .menu li:last-child {
    border: none;
  }
  .has-dropdown:hover .subnav li:last-child {
    margin-bottom: 12px;
  }
  .nav-light .nav-functions i {
    color: #333333 !important;
  }
}
@media all and (max-width: 767px) {
  .nav-1 {
    position: absolute !important;
  }
}
.nav-2 {
  position: fixed;
  padding: 18px 0 12px 0;
  z-index: 99;
  width: 100%;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  max-width: 1580px;
  left: 0;
  right: 0;
  margin: 0 auto;
  background: #333;
  background: rgba(30, 30, 30, 0.4);
}
.nav-2.nav-light {
  background: rgba(255, 255, 255, 0.8);
}
.nav-2 .logo {
  max-height: 25px;
}
.nav-2 .text-right {
  display: inline-block;
  float: right;
}
.nav-2 .social-links,
.nav-1 .social-links {
  position: relative;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.nav-2 .social-links a,
.nav-2 .social-links a {
  opacity: 1;
}
.nav-2 .menu-toggle {
  bottom: 2px;
}
.nav-2 .menu-toggle div {
  background: #fff;
}
.nav-2 .menu-toggle.form-cross {
  bottom: -2px;
}
.nav-2.scrolled {
  padding: 12px 0;
}
.nav-2.scrolled .social-links {
  top: 2px;
}
.menu-toggle {
  position: relative;
  display: inline-block;
  margin-left: 24px;
  cursor: pointer;
  transition: all 0.2s ease;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
}
.menu-toggle.form-cross {
  opacity: 0.6;
  transform: scale(0.7);
  -webkit-transform: scale(0.7);
  bottom: 0;
}
.menu-toggle.form-cross:hover {
  opacity: 1;
}
.menu-toggle.form-cross .bar-3 {
  opacity: 0;
}
.menu-toggle.form-cross .bar-1 {
  transform: rotate(45deg);
  -webkit-transform: rotate(45deg);
}
.menu-toggle.form-cross .bar-2 {
  transform: rotate(-45deg);
  -webkit-transform: rotate(-45deg);
  top: -11px;
}
.nav-2 .menu {
  position: relative;
  max-width: 0;
  transition: all 0.5s ease;
  -webkit-transition: all 0.5s ease;
  -moz-transition: all 0.5s ease;
}
.nav-2 .menu li {
  margin: 0;
  height: 0;
  overflow: hidden;
  transition: all 0.5s ease;
  -webkit-transition: all 0.5s ease;
  -moz-transition: all 0.5s ease;
  opacity: 0;
  padding: 0 18px;
}
.nav-2 .menu li a {
  font-family: 'Montserrat', "Helvetica Neue", Helvetica, Arial, sans-serif;
  text-transform: uppercase;
  font-weight: bold;
  color: #33c68a;
  display: inline-block;
  margin: 24px 0px 16px 0px;
  font-size: 11px;
  color: #fff;
  padding: 0;
  margin: 0;
}
.nav-2 .menu li:last-child {
  padding-right: 32px;
}
.menu.expand {
  max-width: 900px;
}
.menu.expand li {
  height: 24px;
  opacity: 1;
}
.nav-2.nav-light .social-links li a {
  color: #333333;
}
.nav-2.nav-light .bar-1,
.nav-2.nav-light .bar-2,
.nav-2.nav-light .bar-3 {
  background: #333333;
}
.nav-2.nav-light .menu li a {
  color: #333333;
}
.nav-light.scrolled {
  background: rgba(255, 255, 255, 0.9);
}
@media all and (max-width: 768px) {
  .nav-2 .menu li {
    padding-right: 0 !important;
  }
}
@media all and (max-width: 767px) {
  .nav-2 {
    background: rgba(53, 53, 53, 0.4);
    padding: 12px 0;
  }
  .nav-2 .logo {
    max-height: 30px;
  }
  .nav-2 .menu {
    display: block;
    margin: 0;
  }
  .nav-2 .menu.expand {
    margin: 24px 0;
  }
  .nav-2 .menu-toggle {
    top: 3px;
  }
  .nav-2 .social-links {
    top: 4px;
  }
  .nav-2 .menu li {
    padding-right: 0 !important;
  }
  .menu-toggle.form-cross {
    top: 7px;
  }
}
.nav-3 {
  position: fixed;
  top: 0;
  width: 100%;
  z-index: 99;
  padding: 12px 0;
  background: rgba(0, 0, 0, 0.4);
  max-width: 1580px;
  left: 0;
  right: 0;
  margin: 0 auto;
}
.nav-3.nav-light {
  background: rgba(255, 255, 255, 0.8);
}
.nav-3 .logo {
  max-height: 30px;
  position: absolute;
}
.nav-3 .menu-toggle {
  float: right;
  top: 9px;
}
.nav-3 .menu-toggle.form-cross {
  z-index: 101;
  top: 14px;
  opacity: 1;
}
.nav-3 .menu-toggle.form-cross:hover {
  transform: scale(1.1);
}
.fullscreen-container {
  position: fixed;
  width: 100%;
  height: 100%;
  transform: translate3d(0, 100vh, 0);
  -webkit-transform: translate3d(0, 100vh, 0);
  -moz-transform: translate3d(0, 100vh, 0);
  z-index: -1;
  opacity: 1;
  transition: all 0.5s ease;
  -webkit-transition: all 0.5s ease;
  -moz-transition: all 0.5s ease;
  background: rgba(30, 30, 30, 0.9);
  top: 0;
  right: 0;
  left: 0;
  margin-right: auto;
  margin-left: auto;
  max-width: 1580px;
}
.fullscreen-container .menu {
  float: none;
}
.fullscreen-container .logo {
  max-height: 50px;
  display: block;
  margin: 0 auto;
  margin-bottom: 48px;
  position: relative;
}
.fullscreen-container .menu li {
  padding: 0;
  margin: 0 24px;
}
.fullscreen-container .menu li a {
  font-family: 'Montserrat', "Helvetica Neue", Helvetica, Arial, sans-serif;
  text-transform: uppercase;
  font-weight: bold;
  color: #33c68a;
  display: inline-block;
  margin: 24px 0px 16px 0px;
  color: #fff;
  font-size: 12px;
  margin: 0;
}
.fullscreen-container .has-dropdown:hover {
  border: none !important;
}
.fullscreen-container .has-dropdown:hover a {
  margin-bottom: 24px;
}
.fullscreen-container .has-dropdown:hover .subnav li {
  height: 32px;
}
.fullscreen-container .subnav li a {
  margin: 0;
  opacity: 0.7;
  transition: all 0.2s ease;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
}
.fullscreen-container .subnav li a:hover {
  opacity: 1;
}
.fullscreen-container .vertical-align .row {
  transition: all 0.5s ease;
  -webkit-transition: all 0.5s ease;
  -moz-transition: all 0.5s ease;
  opacity: 0;
  transform: translate3d(0, 100px, 0);
  -webkit-transform: translate3d(0, 100px, 0);
  -moz-transform: translate3d(0, 100px, 0);
}
.vertical-align.show-menu .row {
  opacity: 1;
  transform: translate3d(0, 0, 0);
  -webkit-transform: translate3d(0, 0, 0);
  -moz-transform: translate3d(0, 0, 0);
}
.bottom-content {
  position: absolute;
  bottom: 32px;
  width: 100%;
}
.bottom-content .social-links {
  margin-bottom: 18px;
}
.bottom-content .social-links li {
  margin-right: 24px;
}
.bottom-content .social-links a {
  opacity: 0.3;
  color: #fff;
  transition: all 0.2s ease;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
}
.bottom-content .social-links a:hover {
  opacity: 1;
}
.bottom-content span {
  display: block;
  font-size: 12px;
  color: #fff;
  opacity: 0.3;
}
.fullscreen-container.expand {
  z-index: 100;
  opacity: 1;
  transform: translate3d(0, 0, 0);
  -webkit-transform: translate3d(0, 0, 0);
  -moz-transform: translate3d(0, 0, 0);
}
@media all and (max-width: 767px) {
  .nav-3 {
    min-height: 60px;
  }
  .nav-3 .logo {
    position: relative;
    float: left;
  }
  .fullscreen-container .logo {
    max-height: 40px;
    margin-bottom: 12px;
    float: none;
  }
  .fullscreen-container .menu li a {
    padding: 6px 0 !important;
  }
  .bottom-content {
    display: none;
  }
  .fullscreen-container .subnav {
    text-align: center;
  }
  .fullscreen-container .subnav li {
    width: 100%;
    margin: 0 auto;
  }
  .fullscreen-container .has-dropdown:hover .subnav li:last-child {
    margin-bottom: 24px;
  }
  .fullscreen-container .has-dropdown:hover a {
    margin-bottom: 12px;
  }
}
.relative-nav {
  position: relative;
  background: #222;
}
.relative-nav.nav-light {
  background: #fff;
}
.relative-nav.scrolled {
  position: fixed;
  top: 0;
}
.nav-functions {
  display: inline-block;
  float: right;
  position: relative;
  top: 19px;
}
.nav-functions i {
  font-size: 20px;
  color: #fff;
}
.nav-3 .nav-functions {
  top: 5px;
  margin-right: 16px;
}
.nav-functions .search-bar {
  float: left;
  display: inline-block;
  position: relative;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  opacity: 0.8;
  margin-left: 32px;
}
.nav-functions .search-bar:hover {
  opacity: .9;
}
.nav-functions .search-bar:hover input[type="text"] {
  width: 150px;
  opacity: 1;
}
.search-bar input[type="text"] {
  background: none;
  outline: none;
  border: none;
  border-bottom: 1px solid rgba(255, 255, 255, 0.8);
  color: #fff;
  font-weight: 300;
  font-size: 12px;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  width: 0;
  opacity: 0;
  position: relative;
  left: 30px;
  padding-bottom: 2px;
  top: 0;
}
.search-bar input[type="submit"] {
  opacity: 0;
  width: 0;
  height: 0;
  padding: 0;
  overflow: hidden;
}
.search-bar i {
  font-size: 20px;
  color: #fff;
  cursor: pointer;
  position: relative;
  right: 10px;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.nav-light .search-bar input[type="text"] {
  color: #333333 !important;
}
@media all and (max-width: 990px) {
  .nav-functions {
    position: absolute;
    top: 20px;
    right: 93px;
  }
  .nav-3 .nav-functions {
    margin-right: 72px;
  }
}
nav .cart {
  display: inline-block;
  float: right;
  position: relative;
  margin-left: 8px;
}
nav .cart .tag {
  height: 20px;
  width: 20px;
  border-radius: 50%;
  background: #58d4a1;
  color: #fff;
  position: absolute;
  top: -8px;
  right: -13px;
  font-size: 10px;
  text-align: center;
  line-height: 20px;
  font-weight: 700;
}
.icon-large {
  font-size: 80px;
  display: inline-block;
}
/*!
// 7. Headers, sliders, dividers
// --------------------------------------------------*/
.background-image-holder,
.foreground-image-holder {
  position: absolute;
  top: 0px;
  left: 0px;
  width: 100%;
  height: 100%;
  background-size: cover !important;
  z-index: 0;
  opacity: 0;
  transition: opacity 0.5s ease;
  -webkit-transition: opacity 0.5s ease;
  -moz-transition: opacity 0.5s ease;
}
.background-image-holder.parallax-background {
  height: 120%;
  top: -5%;
}
.parallax > .background-image-holder,
.parallax .slides li > .background-image-holder {
  min-height: 100vh;
  top: -50vh;
  transition: all 0s ease !important;
  transition: opacity 0.3s ease !important;
  -webkit-transform-style: preserve-3d;
}
.parallax .hover-background .background-image-holder {
  min-height: 100vh;
  top: -50vh;
}
.parallax:nth-of-type(1) .slides li > .background-image-holder,
.parallax:nth-of-type(1) .background-image-holder {
  top: 0;
}
.background-image-holder .background-image {
  display: none;
}
.fadeIn {
  opacity: 1 !important;
}
.video-holder {
  position: absolute;
  width: 100%;
  height: 100%;
  top: 0;
  left: 0;
}
.video-holder video {
  position: absolute;
  width: 100%;
  height: 150%;
  top: -20%;
  left: 0;
}
@media all and (max-width: 1370px) {
  .video-holder video {
    height: 160%;
    top: -30%;
  }
}
@media all and (max-width: 1260px) {
  .video-holder video {
    height: 170%;
    top: -35%;
    width: 110%;
  }
}
@media all and (max-width: 1130px) {
  .video-holder video {
    height: 200%;
    top: -48%;
    width: 120%;
  }
}
@media all and (max-width: 1000px) {
  .video-holder {
    display: none;
  }
}
.gradient-overlay:before {
  position: absolute;
  width: 100%;
  height: 100%;
  content: '';
  background: #33c68a;
  opacity: 0.8;
  z-index: 2;
}
.fullscreen-element {
  height: 100vh !important;
}
.hover-background .background-image-holder,
.hover-background .foreground-image-holder {
  width: 110%;
  height: 110%;
  top: -5%;
  left: 0%;
}
.hover-background .layer-1,
.hover-background .layer-2 {
  right: -10%;
  overflow: visible;
}
.hero-img{
  /* Add the blur effect */
  filter: blur(4px);
  -webkit-filter: blur(4px);
}
.hover-background .background-image-holder {
  -webkit-transition: all 50ms linear;
  -moz-transition: all 50ms linear;
  -ms-transition: all 50ms linear;
  -o-transition: all 50ms linear;
  transition: all 50ms linear;
}
.hero-slider {
  position: relative;
  overflow: hidden;
  padding: 0;
}
.hero-slider .slides li {
  height: 700px;
  background: #222;
}
.restrict-hero-height {
  max-height: 700px;
}
@media all and (max-width: 767px) {
  .hero-slider .slides li {
    height: 550px;
  }
}
.hero-slider {
  background: #222;
}
.hero-slider .container {
  position: relative;
  z-index: 2;
}
.hero-slider .flex-control-nav {
  bottom: 32px;
  text-align: right;
  padding-right: 64px;
}
.hero-slider .flex-control-nav a {
  width: 8px;
  height: 8px;
  background: none;
  border: 1px solid #fff;
  color: rgba(255, 255, 255, 0);
}
.hero-slider .flex-control-nav a.flex-active {
  background: #fff;
}
.hero-slider h1 {
  font-weight: 300;
}
.hero-slider p.super-lead {
  margin-bottom: 48px;
}
.hero-slider.short-header .slides li {
  height: 450px;
}
@media all and (max-width: 767px) {
  .hero-slider .flex-control-nav {
    display: none;
  }
  .hero-slider.short-header .slides li {
    height: 350px;
  }
}
.hero-slider .alt-font {
  font-size: 64px;
  letter-spacing: 23px;
  margin-right: -23px;
}
.hero-slider .jumbo-h1 {
  font-size: 100px;
  letter-spacing: 10px;
  margin-right: -10px;
  line-height: 116px;
  font-weight: 100;
  max-width: 100%;
}
@media all and (max-width: 767px) {
  .hero-slider .jumbo-h1 {
    font-size: 54px;
    line-height: 64px;
  }
}
.centered-text-slider h1 {
  margin-bottom: 8px;
}
.page-header {
  margin: 0;
  padding: 160px 0;
  border: none;
}
.page-header.short {
  padding: 66.66666667px 0;
}
.page-header .detail-line {
  background: #fff;
  margin-bottom: 24px;
}
.page-header h4 {
  font-weight: 400;
}
.promo-1 {
  padding: 160px 0;
}
.promo-1 .container {
  position: relative;
}
.promo-1 div[class*='col-'] {
  padding: 0;
}
.promo-1 .left-content,
.promo-1 .right-content {
  background: #fff;
  height: 310px;
}
.promo-1 .left-content .vertical-align {
  padding-left: 40px;
}
.promo-1 .right-content {
  background: #33c68a;
  text-align: center;
}
.promo-1 i {
  font-size: 44px;
  color: #333333;
  margin-right: 32px;
  margin-bottom: 24px;
  opacity: 0.5;
}
.promo-1 h4 {
  margin-bottom: 16px;
}
.promo-1 .sub {
  color: #d2f3e6;
  display: block;
  margin-bottom: 32px;
}
.promo-image-holder {
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  position: absolute;
  width: 100%;
  height: 100%;
  top: 0;
}
@media all and (max-width: 767px) {
  .promo-1 {
    padding: 0;
  }
}
.testimonials {
  padding: 120px 0;
  background: #33c68a !important;
}
.testimonials p {
  opacity: .95;
}
.testimonials .alt-font {
  font-size: 12px;
  color: #fff;
  opacity: .95;
}
.testimonials .flex-control-nav {
  bottom: 48px;
}
.testimonials .flex-control-nav li {
  margin: 0 8px;
}
.testimonials .flex-control-nav a {
  width: 12px;
  height: 12px;
  background: none;
  border: 1px solid #58d4a1;
}
.testimonials .flex-control-nav a.flex-active {
  background: #58d4a1;
}
.testimonials .flex-control-nav a:hover {
  background: #58d4a1;
}
@media all and (max-width: 767px) {
  .testimonials {
    padding: 80px 0;
  }
}
.text-divider {
  padding: 200px 0;
}
.text-divider .alt-font {
  font-size: 12px;
  margin-bottom: 24px;
  display: inline-block;
}
.text-divider .text-link {
  font-size: 16px;
}
.signup-divider {
  padding: 240px 0;
}
.signup-divider h1 {
  font-weight: 300;
}
.signup-divider h2 {
  margin-bottom: 48px;
}
.signup-divider input[type="submit"] {
  margin: 0;
  position: relative;
  right: 4px;
  bottom: 1px;
}
.signup-divider input[type="text"] {
  min-width: 300px;
  padding: 16px 0px 17px 16px;
  min-height: 57px;
}
.signup-divider .alert {
  max-width: 400px;
  margin: 0 auto;
  margin-top: 24px;
  display: none;
}
.signup-divider span {
  font-size: 13px;
  display: inline-block;
  margin-top: 16px;
  opacity: 0.9;
}
@media all and (max-width: 767px) {
  .signup-divider {
    padding: 160px 0;
  }
  .signup-divider input[type="text"] {
    min-width: 100%;
    margin-bottom: 16px;
  }
}
.signup-divider.short {
  padding: 160px 0;
}
.signup-divider.short h2 {
  margin-bottom: 18px;
}
.signup-divider.short p.lead {
  margin-bottom: 32px;
}
.signup-divider.short .uppercase {
  margin-top: 0;
}
.stats-large {
  padding: 160px 0px 80px 0px;
}
.stats-large .stat {
  margin-bottom: 80px;
  cursor: default;
}
.stats-large .number {
  font-size: 80px;
  display: inline-block;
  line-height: 88px;
  font-weight: 300;
  transition: all 0.2s ease;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
}
.stats-large h2 {
  margin-bottom: 16px;
}
.stats-large .stat:hover .number {
  transform: translate3d(0, -10px, 0);
  -webkit-transform: translate3d(0, -10px, 0);
  -moz-transform: translate3d(0, -10px, 0);
}
.title-text-divider {
  padding: 160px 0;
}
.title-text-divider h2 {
  font-size: 40px;
  line-height: 48px;
  color: #33c68a;
  margin-bottom: 16px;
}
.title-text-divider h4 {
  color: #58d4a1;
  font-weight: 300;
  margin-bottom: 0;
}
@media all and (max-width: 767px) {
  .title-text-divider h2 {
    font-size: 32px;
    line-height: 36px;
  }
}
.device-divider-1 {
  padding: 0;
  position: relative;
  overflow: hidden;
}
.device-divider-1 img {
  position: relative;
  max-width: 390px;
  top: 80px;
}
.device-divider-1 h2 {
  color: #33c68a;
}
.device-divider-1 .text-link {
  margin-right: 32px;
}
.device-divider-1 .row {
  positon: relative;
  height: 500px;
  overflow: hidden;
}
@media all and (max-width: 990px) {
  .device-divider-1 img {
    max-width: 100%;
  }
}
@media all and (max-width: 768px) {
  .device-divider-1 {
    padding-top: 80px;
  }
  .device-divider-1 .row {
    height: auto;
  }
  .device-divider-1 .row div[class*='col-']:nth-child(2) {
    height: 350px;
    overflow: hidden;
  }
  .device-divider-1 .row div[class*='col-']:nth-child(2) img {
    top: 0;
    margin-top: 32px;
  }
  .device-divider-1 .vertical-align {
    top: 0;
    transform: translateY(0);
  }
}
.text-hero {
  padding: 160px 0;
}
.text-hero h1 {
  color: #33c68a;
  font-size: 64px;
  line-height: 72px;
  font-weight: 300;
}
.text-hero p {
  opacity: 0.8;
}
@media all and (max-width: 1024px) {
  .text-hero br {
    display: none;
  }
}
@media all and (max-width: 767px) {
  .text-hero h1 {
    font-size: 32px;
    line-height: 40px;
  }
}
.text-hero-2 h1 {
  margin-bottom: 64px;
}
.text-hero-2 p.super-lead {
  font-weight: 400;
  font-size: 22px;
  line-height: 40px;
}
@media all and (max-width: 767px) {
  .text-hero-2 h1 {
    margin-bottom: 24px;
  }
  .text-hero-2 p.super-lead {
    font-size: 16px;
    line-height: 28px;
  }
}
.image-tile {
  padding: 48px 0;
  text-align: center;
}
.image-tile h2 {
  font-size: 28px;
  margin-bottom: 0px;
  line-height: 32px;
  transition: all 0.2s ease;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
}
.image-tile .content {
  position: relative;
  z-index: 3;
}
.image-tile p {
  opacity: 0.8;
  transition: all 0.2s ease;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
}
.image-tile:hover h2 {
  transform: translate3d(0px, -5px, 0px);
  -webkit-transform: translate3d(0px, -5px, 0px);
  -moz-transform: translate3d(0px, -5px, 0px);
}
.image-tile:hover p {
  transform: translate3d(0px, 5px, 0px);
  -webkit-transform: translate3d(0px, 5px, 0px);
  -moz-transform: translate3d(0px, 5px, 0px);
  opacity: 1;
}
.dark-action {
  padding: 160px 0;
}
.dark-action .inline-link {
  color: #fff;
}
.dark-action h2 {
  margin-bottom: 16px;
}
.dark-action p {
  margin-bottom: 64px;
}
.dark-action .btn {
  max-width: 900px;
  padding: 19px 24px;
}
.dark-action .btn:nth-of-type(even) {
  margin-left: 0;
}
.dark-action .btn-filled {
  background: #58d4a1;
  color: #fff;
  border-color: #58d4a1;
  position: relative;
}
.dark-action .btn-filled:nth-of-type(even) {
  background: #33c68a;
  border-color: #33c68a;
  right: 4px;
}
@media all and (max-width: 767px) {
  .dark-action .btn-filled:nth-of-type(even) {
    right: 0;
  }
}
.large-image h1 {
  font-weight: 300;
  margin-bottom: 16px;
}
.large-image .logo {
  max-height: 60px;
  display: inline-block;
  margin-bottom: 32px;
}
.large-image h5 {
  margin: 0;
}
.mbYTP_wrapper {
  opacity: 0;
  transition: all 0.5s ease;
  -webkit-transition: all 0.5s ease;
  -moz-transition: all 0.5s ease;
}
.mbYTP_wrapper.active {
  opacity: 1 !important;
}
.buttonBar {
  display: none;
}
/*!
// 8. Short strip sections
// --------------------------------------------------*/
.action-strip-1 .alt-font {
  color: #33c68a;
  font-size: 24px;
  display: block;
  margin-bottom: 8px;
}
.action-strip-1 .title {
  color: #58d4a1;
  margin-bottom: 24px;
  display: block;
}
.action-strip-1 i {
  color: #33c68a;
  font-size: 36px;
}
.action-strip-1 .text-link,
.action-strip-3 .text-link {
  margin-left: 8px;
  position: relative;
  bottom: 14px;
}
.action-strip-2 h2 {
  color: #33c68a;
}
.action-strip-2 .btn {
  padding: 19px 28px;
}
.action-strip-3 i {
  font-size: 36px;
}
.action-strip-3 .text-link:hover {
  border-color: #fff;
}
.action-strip-3 .ext-link:hover i {
  color: #fff;
}
.action-strip-3 h2 {
  margin-bottom: 48px;
}
.check-feature * {
  display: inline-block;
  margin-bottom: 48px;
}
.check-feature i {
  font-size: 48px;
  margin-right: 24px;
  transition: all 0.2s ease;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
}
.check-feature:hover i {
  transform: scale(1.1) rotate(10deg);
}
.strip div[class*='col-'] {
  position: relative;
}
.strip span {
  font-size: 24px;
  color: #33c68a;
}
.strip .btn {
  position: absolute;
  right: 0;
  top: -2px;
  z-index: 2;
}
.strip .sub {
  display: block;
  color: #58d4a1;
  font-size: 18px;
  margin-top: 4px;
}
@media all and (max-width: 767px) {
  .strip .btn {
    position: relative;
    margin-top: 24px;
  }
}
.video-strip {
  position: relative;
  padding: 120px 0;
  transition: all 0.5s ease;
  -webkit-transition: all 0.5s ease;
  -moz-transition: all 0.5s ease;
}
.video-strip .pre-video i {
  cursor: pointer;
  display: inline-block;
  width: 80px;
  height: 80px;
  border-radius: 50%;
  border: 2px solid #33c68a;
  text-align: center;
  padding-top: 20px;
  padding-left: 10px;
  font-size: 40px;
  color: #33c68a;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  transform: translate3d(0, 0, 0);
  -webkit-transform: translate3d(0, 0, 0);
  -moz-transform: translate3d(0, 0, 0);
  opacity: 1;
}
.video-strip h2 {
  margin: 0;
  transform: translate3d(0, 0, 0);
  -webkit-transform: translate3d(0, 0, 0);
  -moz-transform: translate3d(0, 0, 0);
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  display: inline-block;
  margin-left: 24px;
  position: relative;
  bottom: 8px;
}
.video-strip:hover h2 {
  transform: translate3d(8px, 0, 0);
  -webkit-transform: translate3d(8px, 0, 0);
  -moz-transform: translate3d(8px, 0, 0);
}
.video-strip:hover .pre-video i {
  transform: translate3d(-8px, 0, 0);
  -webkit-transform: translate3d(-8px, 0, 0);
  -moz-transform: translate3d(-8px, 0, 0);
  opacity: 1;
}
.video-strip .pre-video i:hover {
  background: #33c68a;
  color: #fff;
  transform: translateX(-8px) scale(1.2);
}
.pre-video {
  transition: all 0.5s ease;
  -webkit-transition: all 0.5s ease;
  -moz-transition: all 0.5s ease;
  max-height: 200px;
}
.video-strip .iframe-holder {
  max-width: 890px;
  text-align: right;
  margin: 0 auto;
  transition: all 0.5s ease;
  -webkit-transition: all 0.5s ease;
  -moz-transition: all 0.5s ease;
  max-height: 0;
  overflow: hidden;
  opacity: 0;
}
.iframe-holder iframe {
  border: 0;
  width: 100%;
  height: 500px;
}
.iframe-holder i {
  display: inline-block;
  margin-bottom: 24px;
  font-size: 40px;
  color: #33c68a;
  cursor: pointer;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.iframe-holder i:hover {
  transform: scale(1.2);
}
iframe {
  border: none !important;
}
.show-iframe {
  max-height: 800px !important;
  overflow: visible !important;
}
.fade-off {
  opacity: 0;
  max-height: 0;
}
.fade-on {
  opacity: 1 !important;
}
.clients-1 {
  background: #33c68a !important;
  padding: 120px 0 40px 0;
}
.clients-1 img {
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  max-height: 30px;
  opacity: 0.3;
  display: inline-block;
  margin-bottom: 80px;
}
.clients-1 img:hover {
  opacity: .5;
}
.clients-1 h1 {
  font-weight: 300;
}
.clients-1 .text-block {
  margin-bottom: 64px;
  opacity: 0.9;
}
@media all and (max-width: 767px) {
  .clients-1 img {
    margin-bottom: 40px;
  }
}
.countdown-row {
  display: block !important;
  width: 100%;
}
.countdown-row span {
  color: #fff;
  font-weight: 300;
  opacity: 1 !important;
}
.countdown-section {
  width: 25%;
  display: inline-block;
}
.countdown-amount {
  display: inline-block;
  margin-bottom: 32px;
  color: #fff;
  font-size: 80px !important;
}
.countdown-period {
  display: block !important;
  font-size: 18px !important;
}
.signup-divider .countdown {
  margin-bottom: 40px;
}
@media all and (max-width: 767px) {
  .countdown-amount {
    font-size: 40px !important;
  }
}
/*!
// 9. Text-based sections
// --------------------------------------------------*/
.text-block h4 {
  margin-bottom: 48px;
}
.text-block h2 {
  margin-bottom: 24px;
}
.text-block .btn {
  margin-top: 16px;
}
.text-block .text-link {
  margin-top: 24px;
}
.text-block.text-center .detail-line {
  display: inline-block;
}
.col-3-text {
  padding: 80px 0px 40px 0px;
}
.col-3-text div[class*='col-'] {
  margin-bottom: 40px;
}
.image-block {
  padding: 0 0;
  position: relative;
}
.image-block-portability {
  padding: 10% 0;
  position: relative;
}
@media all and (max-width: 768px) {
  .image-block {
    padding: 0px 0;
  }
  .image-block-portability {
  padding: 9% 0;
  position: relative;
  }
}
.uppercase {
  text-transform: uppercase;
  font-weight: bold;
  color: #33c68a;
  display: inline-block;
  margin: 24px 0px 16px 0px;
}
.image-block .image-holder {
  background: #fff;
  position: absolute;
  height: 100%;
  padding: 0;
  top: 0;
}
.image-block-portability .image-holder{
  background: #fff;
  position: absolute;
  height: 100%;
  padding: 0;
  top: 0;
  }
.image-holder.pull-right {
  right: 0;
}
.image-holder.pull-left {
  left: 0;
}
.image-block.short-pad {
  padding: 80px 0;
}
.image-holder .image-slider {
  position: absolute;
  width: 100%;
  height: 100%;
  top: 0;
  left: 0;
}
.image-holder .slides {
  height: 100%;
}
.image-holder .slides li {
  height: 100%;
  width: 100%;
}
.image-holder .image-slider .flex-control-nav li a {
  border: 1px solid #fff;
  background: rgba(255, 255, 255, 0);
}
.image-holder .image-slider .flex-control-nav li a.flex-active {
  background: rgba(255, 255, 255, 0.7);
}
.image-holder iframe {
  width: 100%;
  height: 100%;
  position: absolute;
}
.image-holder h3 {
  color:#000;
  font-size: 22px;
  text-align: center;
  font-weight: 400;
  line-height: 28px;
  margin-bottom: 25px;
}
.embed-holder:before {
  position: absolute;
  width: 100%;
  height: 85%;
  top: 0;
  content: '';
  z-index: 1;
}

@media all and (max-width: 990px) {
  .image-block {
   /* padding: 20px;*/
  }
  .image-block .image-holder {
    position: relative;
    width: 100%;
/*    height: 300px;*/
    margin-top: 80px;
  }
  .image-block.short-pad .image-holder {
    display: none;
  }
}
.feature-lists {
  padding: 80px 0 40px 0;
}
.feature-lists.large-pad {
  padding: 120px 0 80px 0;
}
.feature-list {
  margin-bottom: 40px;
}
.feature-lists i {
  color: #33c68a;
  margin-bottom: 8px;
}
.feature-lists ul {
  margin-top: 24px;
}
.arrow-list li:before {
  font-family: 'themify';
  speak: none;
  font-style: normal;
  font-weight: normal;
  font-variant: normal;
  text-transform: none;
  line-height: 1;
  -webkit-font-smoothing: antialiased;
  content: "\e628";
  color: #33c68a;
  font-size: 12px;
  display: inline-block;
  margin-right: 18px;
  position: relative;
  top: 0px;
}
.arrow-list li {
  color: #333333;
  margin-bottom: 4px;
}
.arrow-list li a {
  color: #33c68a;
}
.color-feature {
  padding: 80px;
  min-height: 573px;
}
@media all and (max-width: 1024px) {
  .color-feature {
    padding: 53.33333333px;
  }
}
.color-feature .detail-line {
  background-color: #fff;
}
.color-feature h5.alt-font {
  font-size: 12px;
  line-height: 16px;
}
.color-feature i {
  font-size: 120px;
  display: inline-block;
  margin: 32px 0px 48px 0px;
  color: #fff;
}
.color-features div[class*='col-']:nth-child(1) {
  background: #33c68a;
}
.color-features div[class*='col-']:nth-child(1) i {
  color: #58d4a1;
}
.color-features div[class*='col-']:nth-child(2) {
  background: #58d4a1;
}
.color-features div[class*='col-']:nth-child(2) i {
  color: #81deb8;
}
.color-features div[class*='col-']:nth-child(3) {
  background: #68d8aa;
}
.color-features div[class*='col-']:nth-child(3) i {
  color: #8de2bf;
}
@media all and (max-width: 1200px) {
  .color-feature {
    padding: 80px 53.33333333px;
    min-height: auto;
  }
}
@media all and (max-width: 900px) {
  .color-feature {
    padding: 80px 40px;
  }
}
.skills-wrapper {
  border: 1px solid rgba(0, 0, 0, 0.1);
  text-align: center;
  overflow: hidden;
}
.skills-wrapper .skill {
  width: 50%;
  float: left;
  padding: 40px;
}
.skills-wrapper .skill i,
.skills-wrapper .skill .number {
  font-size: 48px;
  color: #33c68a;
  line-height: 56px;
}
.skills-wrapper .skill .number {
  font-weight: bold;
}
.skills-wrapper .skill i {
  display: inline-block;
  margin-right: 8px;
  position: relative;
  top: 5px;
}
.skills-wrapper .skill .sub {
  display: block;
  color: #58d4a1;
}
.skills-wrapper .skill:nth-child(odd) {
  border-right: 1px solid rgba(0, 0, 0, 0.1);
}
.skills-wrapper .skill:nth-child(n+2) {
  border-top: 1px solid rgba(0, 0, 0, 0.1);
}
@media all and (max-width: 990px) {
  .skills-wrapper {
    margin-top: 32px;
  }
  .skills-wrapper .skill {
    width: 100%;
  }
}
.wide-features {
  padding: 80px 0px 40px 0px;
}
.wide-feature {
  margin-bottom: 40px;
}
.wide-feature p {
  width: 80%;
}
.wide-feature .text-link {
  margin-top: 24px;
}
.wide-feature i {
  font-size: 64px;
  color: #58d4a1;
  display: inline-block;
  margin-bottom: 16px;
}
.wide-feature h2 {
  color: #33c68a;
}
@media all and (max-width: 1200px) {
  .wide-feature p {
    width: 100%;
  }
}
.narrow-features {
  padding: 80px 0 40px 0;
}
.narrow-feature {
  overflow: hidden;
  margin-bottom: 40px;
}
.narrow-feature i {
  color: #33c68a;
  font-size: 48px;
  display: inline-block;
  width: 20%;
  float: left;
}
.narrow-feature .content {
  display: inline-block;
  width: 80%;
  float: left;
}
.narrow-feature h5 {
  color: #33c68a;
  margin-bottom: 8px;
}
.large-cto {
  padding: 120px 0;
  position: relative;
  overflow: hidden;
}
.large-cto .pull-right {
  right: 0;
}
.large-cto-holder {
  position: absolute;
  padding: 0;
  height: 100%;
  top: 0;
}
@media all and (max-width: 767px) {
  .large-cto {
    padding-bottom: 0;
  }
  .large-cto-holder {
    position: relative;
    height: 560px;
    margin-top: 40px;
  }
}
.large-cto-holder .cto:nth-child(1) {
  background: #33c68a;
  height: 50%;
}
.large-cto-holder .cto:nth-child(2) {
  background: #58d4a1;
  height: 50%;
}
.large-cto-holder .cto {
  padding: 0 80px;
  overflow: hidden;
  position: relative;
}
.cto .title {
  font-size: 20px;
  line-height: 28px;
  font-weight: 700;
}
.cto .sub {
  display: block;
  margin-bottom: 24px;
}
.cto .text-link:hover {
  border-color: #fff;
}
.cto .large-icon {
  position: absolute;
  display: block;
  font-size: 270px;
  top: 0;
  right: 0;
  opacity: 0.03;
  transition: all 0.3s ease-out;
  -webkit-transition: all 0.3s ease-out;
  -moz-transition: all 0.3s ease-out;
  transform: rotate(45deg) scale(4);
  color: #fff;
}
.cto:hover .large-icon {
  transform: rotate(0deg) scale(1);
  opacity: 0.09;
}
.careers .detail-line {
  background: #fff;
}
.careers .text-block {
  margin-bottom: 64px;
}
.job-desc {
  margin-bottom: 40px;
}
.job-desc a {
  font-size: 24px;
  font-weight: 300;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  display: inline-block;
  margin-bottom: 16px;
}
.job-desc i {
  position: relative;
  transition: all 0.1s ease-out;
  -webkit-transition: all 0.1s ease-out;
  -moz-transition: all 0.1s ease-out;
  left: 0;
}
.job-desc a:hover i {
  left: 5px;
}
.job-desc p {
  max-width: 90%;
}
@media all and (max-width: 990px) {
  .job-desc p {
    max-width: 100%;
  }
}
.careers .sub {
  font-size: 13px;
  display: inline-block;
  margin-right: 8px;
}
.careers a.sub:hover {
  border-color: #fff;
}
.cto-features {
  padding-bottom: 40px;
}
.cto-features .text-block {
  padding-top: 60px;
}
.cto-features .row:first-child {
  padding-bottom: 40px;
  border-bottom: 1px solid #ccc;
  margin-bottom: 80px;
}
.cto-features .wide-feature p {
  margin: 0 auto;
  display: block;
}
.cto-features .wide-feature .cto-icon {
  font-size: 80px;
}
@media all and (max-width: 767px) {
  .cto-features .text-block {
    margin-bottom: 32px;
  }
}
.image-features {
  padding-bottom: 40px;
}
.image-feature {
  text-align: center;
  margin-bottom: 40px;
}
.image-feature img {
  max-height: 170px;
  display: inline-block;
  margin-bottom: 32px;
}
.box-features {
  padding-bottom: 40px;
}
.box-feature {
  text-align: center;
  overflow: hidden;
  margin-bottom: 40px;
}
.box-left,
.box-right {
  height: 285px;
  width: 50%;
  float: left;
}
.box-left {
  background: #33c68a;
  color: #fff;
}
.box-left i {
  font-size: 42px;
  display: inline-block;
  margin-bottom: 16px;
}
.box-left h5 {
  color: #fff;
  margin: 0 auto;
  line-height: 32px;
  font-size: 24px;
  font-weight: 300;
}
.box-right {
  padding: 0 24px;
  background: #fff;
}
.box-right .uppercase {
  font-size: 12px;
  color: #333333;
}
@media all and (max-width: 1200px) {
  .box-right,
  .box-left {
    width: 100%;
    height: 250px;
  }
  .box-right {
    padding: 0 48px;
  }
  .box-left {
    padding: 0 24px;
  }
}
.info-panel {
  border: 1px solid #ccc;
  margin-bottom: 40px;
}
.info-panel .title {
  padding: 18px 24px;
  border-bottom: 1px solid #ccc;
  background: #fff;
}
.info-panel .title h4 {
  margin: 0;
  font-weight: 300;
}
.info-panel .body {
  padding: 18px 24px;
  background: #f7f7f7;
}
.info-panels {
  padding: 80px 0 40px 0;
}
.info-panels:nth-child(odd) .info-panel .body {
  background: #fff;
}
.info-panels:nth-child(odd) .info-panel .title {
  background: #f7f7f7;
}
.info-panel-slim {
  margin-bottom: 40px;
}
.timeline-1 {
  padding: 120px 0;
}
.timeline-1 .overlay:before {
  opacity: 0.5;
}
.timeline-section h2,
.timeline-section p {
  cursor: default;
}
.timeline-section {
  display: inline-block;
  overflow: hidden;
  position: relative;
  padding-top: 20px;
  width: 100%;
  margin-bottom: -7px;
}
.timeline-content {
  float: left;
}
.timeline-section .right-content {
  float: right;
  width: 50%;
}
.timeline-section .left-content {
  width: 50%;
  text-align: right;
}
.timeline-section h2 {
  font-size: 24px;
  margin-bottom: 8px;
}
.timeline-section .left-content {
  padding-right: 40px;
  border-right: 2px solid #fff;
  padding-bottom: 32px;
  position: relative;
}
.timeline-section .left-content:before {
  content: '';
  width: 20px;
  height: 20px;
  border-radius: 50%;
  border: 2px solid #fff;
  position: absolute;
  right: 0;
  margin-right: -11px;
  margin-top: -20px;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.timeline-section .left-content p {
  max-width: 400px;
  float: right;
}
.timeline-section:hover .left-content:before {
  background: rgba(255, 255, 255, 0.5);
}
.timeline-section .right-content {
  padding-left: 40px;
  text-align: left;
}
.timeline-section .right-content i,
.timeline-section .left-content i {
  font-size: 48px;
}
.timeline-section .right-content p {
  max-width: 400px;
  float: left;
}
.timeline-section:nth-child(even) .left-content {
  border-right: none;
  padding-bottom: 0;
}
.timeline-section:nth-child(even) {
  position: relative;
  right: 2px;
}
.timeline-section:nth-child(even) .right-content {
  border-left: 2px solid #fff;
  padding-bottom: 32px;
}
.timeline-section:last-child {
  text-align: center;
  padding-bottom: 20px;
}
.timeline-section:last-child:after {
  content: '';
  width: 20px;
  height: 20px;
  border-radius: 50%;
  border: 2px solid #fff;
  position: absolute;
  bottom: 0;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  left: 50%;
  margin-left: -9px;
  margin-top: 20px;
}
.timeline-section:last-child:after:hover {
  background: rgba(255, 255, 255, 0.5);
}
@media all and (max-width: 767px) {
  .timeline-section .left-content,
  .timeline-section .right-content {
    border: none !important;
    padding-right: 0 !important;
    padding-left: 0 !important;
    width: 100%;
    text-align: left !important;
  }
  .timeline-section .left-content:before {
    display: none;
  }
  .timeline-section i {
    display: none;
  }
  .timeline-section:last-child:after {
    display: none;
  }
}
.text-list p.super-lead {
  margin-bottom: 80px;
}
.text-list h2 {
  color: #33c68a;
  margin-bottom: 16px;
}
.text-list .item {
  overflow: hidden;
  border-bottom: 1px solid rgba(0, 0, 0, 0.15);
  padding-bottom: 32px;
  margin-bottom: 32px;
}
.text-list .item:last-child {
  margin-bottom: 0;
  border-bottom: none;
}
.text-list .description {
  width: 70%;
  float: left;
}
.text-list .action {
  width: 30%;
  float: left;
  text-align: right;
}
.text-list .text-link {
  margin-right: 24px;
}
@media all and (max-width: 767px) {
  .text-list .description {
    width: 100%;
    margin-bottom: 24px;
  }
  .text-list .action {
    width: auto;
  }
}
.fullwidth-features {
  padding: 0;
  background: #33c68a !important;
  position: relative;
  overflow: visible;
  height: 250px;
}
.fullwidth-features div[class*="col-"] {
  padding: 0;
}
.fullwidth-feature {
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  position: absolute;
  z-index: 10;
  cursor: pointer;
  min-width: 100%;
  float: left;
}
.fullwidth-feature .top {
  background: #33c68a;
  padding: 80px;
  text-align: center;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  border-right: 1px solid #58d4a1;
}
.fullwidth-feature .detail-line {
  background: #d2f3e6;
  margin: 0 auto;
}
.fullwidth-feature i {
  font-size: 36px;
  color: #fff;
  display: inline-block;
  margin-bottom: 8px;
}
.fullwidth-feature h5 {
  color: #fff;
  margin: 0;
  margin-bottom: 16px;
}
.fullwidth-feature .bottom {
  padding: 64px 40px 64px 40px;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  border-right: 1px solid #81deb8;
  background: #58d4a1;
  color: #fff;
}
.fullwidth-feature p {
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  color: #fff;
  max-height: 0;
  overflow: hidden;
  opacity: 0;
}
.fullwidth-feature:hover p {
  max-height: 500px;
  opacity: 1;
  padding-top: 48px;
}
.fullwidth-feature:hover {
  transform: translate3d(0, -75px, 0);
  -webkit-transform: translate3d(0, -75px, 0);
  -moz-transform: translate3d(0, -75px, 0);
  border-right: none;
}
@media all and (max-width: 990px) {
  .fullwidth-features {
    height: 175px;
  }
  .fullwidth-feature .top {
    padding: 40px;
  }
}
@media all and (max-width: 767px) {
  .fullwidth-features {
    height: auto;
    overflow: hidden;
  }
  .fullwidth-feature {
    position: relative;
    border-bottom: 1px solid #58d4a1;
  }
  .fullwidth-feature .top {
    padding: 64px 24px;
  }
  .fullwidth-feature:hover {
    transform: translate3d(0, 0, 0);
    -webkit-transform: translate3d(0, 0, 0);
    -moz-transform: translate3d(0, 0, 0);
  }
}
.expanding-list {
  margin-bottom: 24px;
}
.expanding-list .title {
  display: block;
  padding: 8px 0;
  border-bottom: 1px solid #ccc;
  cursor: pointer;
  font-size: 16px;
}
.expanding-list .content {
  max-height: 0;
  opacity: 0;
  transition: all 0.4s ease;
  -webkit-transition: all 0.4s ease;
  -moz-transition: all 0.4s ease;
  cursor: default;
  overflow: hidden;
}
.expanding-list li {
  transition: all 0.4s ease;
  -webkit-transition: all 0.4s ease;
  -moz-transition: all 0.4s ease;
}
.expanding-list li.active {
  padding-bottom: 16px;
}
.expanding-list li.active .content {
  max-height: 900px;
  opacity: 1;
}
.review {
  padding: 18px;
  background: #f7f7f7;
  margin-bottom: 18px;
}
.review .author {
  font-style: italic;
}
.review p {
  display: block;
  margin-top: 16px;
}
.review:last-child {
  margin-bottom: 0;
}
.add-to-cart {
  overflow: hidden;
  display: inline-block;
  width: 100%;
}
.quantity-controls {
  border: 1px solid #ccc;
  display: inline-block;
  overflow: hidden;
}
.add-to-cart .more,
.add-to-cart .less {
  height: 40px;
  width: 40px;
  text-align: center;
  line-height: 40px;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  cursor: pointer;
  font-size: 20px;
  float: left;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.add-to-cart .more:hover,
.add-to-cart .less:hover {
  background: #33c68a;
  color: #fff;
  border-color: #33c68a;
}
.more {
  border-left: 1px solid #ccc;
}
.less {
  border-right: 1px solid #ccc;
}
.add-to-cart input[type="text"] {
  width: 40px;
  height: 40px;
  float: left;
  text-align: center;
  border: none;
  color: #33c68a;
}
.add-to-cart input[type="submit"] {
  float: right;
  min-height: 40px;
  background: none;
}
.add-to-cart input[type="submit"]:hover {
  border-color: #33c68a;
}
.side-icon-feature {
  overflow: hidden;
  margin-bottom: 64px;
}
.side-icon-feature:last-child {
  margin-bottom: 0;
}
.side-icon-feature h5 {
  margin-bottom: 16px;
}
.services-combo-1 {
  background: #33c68a !important;
  padding: 120px 0;
  position: relative;
}
.services-combo-1 .icon {
  width: 20%;
  float: left;
}
.services-combo-1 i {
  color: #d2f3e6;
  font-size: 80px;
  display: inline-block;
}
.services-combo-1 .content {
  display: inline-block;
  width: 80%;
}
.services-combo-1 p.lead {
  margin-bottom: 48px;
}
.services-combo-1 .btn-filled {
  background: #58d4a1;
  border-color: #58d4a1;
}
.services-combo-1 .btn-filled:hover {
  background: #fff;
  color: #58d4a1;
  border-color: #fff;
}
.services-combo-1 .jumbo {
  position: absolute;
  font-size: 700px;
  color: #58d4a1;
  opacity: 0.2;
  bottom: -150px;
  left: -100px;
  transform: rotate(45deg);
}
@media all and (max-width: 767px) {
  .services-combo-1 .btn {
    margin-bottom: 40px;
  }
  .services-combo-1 i {
    font-size: 40px;
  }
}
/*!
// 10. Team
// --------------------------------------------------*/
.team-1-single h4 {
  letter-spacing: 3px;
  margin-bottom: 0px;
  color: #333333;
}
.team-1-single img {
  max-width: 350px;
  display: inline-block;
}
.team-1-single .sub {
  font-size: 11px;
  letter-spacing: 2px;
  display: inline-block;
  margin-bottom: 24px;
}
.team-1-single .social-links {
  margin-top: 16px;
}
.team-1-single h3 {
  color: #333333;
  margin-bottom: 8px;
}
.team-1-single.dark-bg h4 {
  color: #fff;
}
.team-1-single.dark-bg p {
  color: #fff;
}
.team-1-single.dark-bg span {
  color: #fff;
}
.team-1-single.dark-bg .social-links a {
  color: #fff;
}
@media all and (max-width: 768px) {
  .team-1-single img {
    max-width: 250px;
    margin-top: 0;
  }
}
.team-1-single {
  background: #eeeeee;
  /* Old browsers */
  background: -moz-radial-gradient(center, ellipse cover, #eeeeee 0%, #dddddd 100%) !important;
  /* FF3.6+ */
  background: -webkit-gradient(radial, center center, 0px, center center, 100%, color-stop(0%, #eeeeee), color-stop(100%, #dddddd)) !important;
  /* Chrome,Safari4+ */
  background: -webkit-radial-gradient(center, ellipse cover, #eeeeee 0%, #dddddd 100%) !important;
  /* Chrome10+,Safari5.1+ */
  background: -o-radial-gradient(center, ellipse cover, #eeeeee 0%, #dddddd 100%) !important;
  /* Opera 12+ */
  background: -ms-radial-gradient(center, ellipse cover, #eeeeee 0%, #dddddd 100%) !important;
  /* IE10+ */
  background: radial-gradient(ellipse at center, #eeeeee 0%, #dddddd 100%) !important;
  /* W3C */
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#eeeeee', endColorstr='#dddddd', GradientType=1);
  /* IE6-9 fallback on horizontal gradient */
  padding-bottom: 0;
  padding-top: 120px;
}
.team-1-single.dark-bg {
  background: #333333;
  /* Old browsers */
  background: -moz-radial-gradient(center, ellipse cover, #3b3b3b 0%, #222222 100%) !important;
  /* FF3.6+ */
  background: -webkit-gradient(radial, center center, 0px, center center, 100%, color-stop(0%, #3b3b3b), color-stop(100%, #222222)) !important;
  /* Chrome,Safari4+ */
  background: -webkit-radial-gradient(center, ellipse cover, #3b3b3b 0%, #222222 100%) !important;
  /* Chrome10+,Safari5.1+ */
  background: -o-radial-gradient(center, ellipse cover, #3b3b3b 0%, #222222 100%) !important;
  /* Opera 12+ */
  background: -ms-radial-gradient(center, ellipse cover, #3b3b3b 0%, #222222 100%) !important;
  /* IE10+ */
  background: radial-gradient(ellipse at center, #3b3b3b 0%, #222222 100%) !important;
  /* W3C */
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr='#3b3b3b', endColorstr='#222222', GradientType=1) !important;
  /* IE6-9 fallback on horizontal gradient */
  padding-bottom: 0;
  padding-top: 120px;
}
.social-links {
  overflow: hidden;
  display: inline-block;
}
.social-links li {
  float: left;
  margin-right: 16px;
}
.social-links li:last-child {
  margin-right: 0;
}
.social-links a {
  font-size: 18px;
  color: #333333;
}
.member-spotlight img {
  display: inline-block;
  margin-bottom: 16px;
}
@media all and (max-width: 768px) {
  .member-spotlight img {
    margin-top: 32px;
  }
}
.member-spotlight .title {
  font-size: 12px;
  color: #33c68a;
}
@media all and (max-width: 990px) {
  .short-pad.image-block .background-image-holder {
    display: none;
  }
}
.team-2 .text-block {
  margin-bottom: 64px;
}
.team-2 .team-member {
  margin-bottom: 40px;
}
.team-2 img {
  display: inline-block;
  margin-bottom: 16px;
}
.team-2 h3 {
  margin-bottom: 8px;
  color: #333333;
}
.team-2 span {
  font-style: italic;
  color: #33c68a;
  display: inline-block;
  margin-bottom: 24px;
}
.team-2 p {
  padding-right: 36px;
}
@media all and (max-width: 990px) {
  .team-2 p {
    padding-right: 0;
  }
}
/*!
// 11. Portfolio & Gallery
// --------------------------------------------------*/
.project {
  position: relative;
  overflow: hidden;
}
.fullscreen-projects .project {
  padding: 0;
  width: 50%;
  height: 650px;
}
@media all and (max-width: 1200px) {
  .fullscreen-projects .project {
    width: 50%;
    height: 400px;
  }
}
@media all and (max-width: 767px) {
  .fullscreen-projects .project {
    width: 100%;
    height: 325px;
  }
}
.hover-state {
  position: absolute;
  width: 100%;
  height: 100%;
  top: 0;
  left: 0;
  background: rgba(0, 0, 0, 0.4);
  transition: all 0.3s ease-out;
  -webkit-transition: all 0.3s ease-out;
  -moz-transition: all 0.3s ease-out;
  opacity: 0;
  -webkit-transform-style: preserve-3d;
  -moz-transform-style: preserve-3d;
  transform-style: preserve-3d;
}
.hover-state a {
  display: block;
}
.hover-state .detail-line {
  background: #fff;
}
.hover-state .vertical-align {
  width: 250px;
  text-align: left;
  left: 50%;
  margin-left: -125px;
}
.hover-state .hover-content {
  transform: translate3d(0, 100px, 0);
  -webkit-transform: translate3d(0, 100px, 0);
  -moz-transform: translate3d(0, 100px, 0);
  opacity: 0;
  transition: all 0.3s ease-out;
  -webkit-transition: all 0.3s ease-out;
  -moz-transition: all 0.3s ease-out;
}
.hover-state:hover .hover-content {
  transform: translate3d(0, 0, 0);
  -webkit-transform: translate3d(0, 0, 0);
  -moz-transform: translate3d(0, 0, 0);
  opacity: 1;
}
.hover-content h4 {
  margin-bottom: 8px;
}
.hover-content i {
  font-size: 28px;
  color: #fff;
  position: relative;
  transition: all 0.2s ease-out;
  -webkit-transition: all 0.2s ease-out;
  -moz-transition: all 0.2s ease-out;
  transform: translate3d(-20px, 0, 0);
  -webkit-transform: translate3d(-20px, 0, 0);
  -moz-transform: translate3d(-20px, 0, 0);
  opacity: 0;
}
.hover-content:hover i {
  opacity: 1;
  transform: translate3d(0px, 0, 0);
  -webkit-transform: translate3d(0px, 0, 0);
  -moz-transform: translate3d(0px, 0, 0);
}
.force-hover .hover-content i {
  opacity: 1;
  transform: translate3d(0, 0, 0);
  -webkit-transform: translate3d(0, 0, 0);
  -moz-transform: translate3d(0, 0, 0);
}
.force-hover .hover-state {
  opacity: 1;
}
.force-hover .hover-content {
  transform: translate3d(0, 0, 0);
  -webkit-transform: translate3d(0, 0, 0);
  -moz-transform: translate3d(0, 0, 0);
  opacity: 1;
}
.project:hover .hover-state {
  opacity: 1;
}
.project .background-image-holder {
  transition: all 0.3s ease-out;
  -webkit-transition: all 0.3s ease-out;
  -moz-transition: all 0.3s ease-out;
  transform: scale(1);
  -webkit-transform: scale(1);
}
.project:hover .background-image-holder {
  transform: scale(1.02);
  -webkit-transform: scale(1.02);
}
.project .background-image-holder.zoom {
  transform: scale(1.04);
  -webkit-transform: scale(1.04);
}
.hero-project {
  overflow: hidden;
}
.hero-project .background-image-holder {
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.hero-project:hover .background-image-holder {
  transform: scale(1.02);
}
.hero-project .detail-line {
  background: #fff;
}
.hero-project .text-block {
  margin-bottom: 160px;
}
@media all and (max-width: 767px) {
  .hero-project .text-block {
    margin-bottom: 80px;
  }
}
.lightbox-gallery1 h2 {
  color: #33c68a;
  margin-bottom: 8px;
}
.lightbox-gallery1 h5 {
  color: #58d4a1;
}
.lightbox-gallery1 p {
  margin-bottom: 64px;
}
.lightbox-container {
  overflow: hidden;
}
.lightbox-container div[class*='col-'] {
  position: relative;
  overflow: hidden;
}
.lightbox-container div[class*='col-'] a:last-child {
  margin-bottom: 0;
}
.lightbox-container a {
  overflow: hidden;
  display: inline-block;
  width: 100%;
  position: relative;
}
.lightbox-container .col-md-8 a {
  height: 450px;
}
.lightbox-container .col-md-4 a {
  margin-bottom: 30px;
  height: 206px;
}
.lightbox-container .background-image-holder {
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.lightbox-container a:hover .background-image-holder {
  transform: scale(1.03);
}
.uneven-projects {
  padding: 0;
}
.uneven-projects .project {
  height: 360px;
}
.uneven-projects .col-md-6 .hover-state {
  background: rgba(51, 198, 138, 0.7);
}
.uneven-projects .project .background-image-holder {
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.uneven-projects .project:hover .background-image-holder {
  transform: scale(1.05);
}
.project.col-md-3 h4 {
  font-weight: 400;
  font-size: 18px;
  line-height: 24px;
}
.project.col-md-3 h5 {
  font-size: 14px;
  margin-bottom: 12px;
}
.contained-projects {
  padding: 80px 0 40px 0;
}
.contained-projects .text-block {
  margin-bottom: 80px;
}
.contained-projects .background-image-holder {
  position: relative;
  width: 100%;
  height: 200px;
  margin-bottom: 18px;
}
.contained-projects .project {
  margin-bottom: 40px;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  opacity: 1;
}
.contained-projects .project h2 {
  margin-bottom: 8px;
  color: #33c68a;
}
.contained-projects .project span {
  display: inline-block;
  margin-bottom: 16px;
}
.contained-projects .project h5 {
  margin: 0;
}
.contained-projects .project:hover .background-image-holder {
  transform: scale(1) !important;
  -webkit-transform: scale(1) !important;
}
.contained-projects .inactive {
  opacity: 0.1;
}
.contained-projects .inactive a {
  cursor: default;
}
@media all and (max-width: 900px) {
  .contained-projects .project {
    width: 50%;
  }
}
@media all and (max-width: 767px) {
  .contained-projects .project {
    width: 100%;
  }
}
.filters {
  overflow: hidden;
  margin-bottom: 48px;
  display: inline-block;
}
.filters li {
  float: left;
  margin-right: 32px;
  border: 2px solid #ccc;
  color: #ccc;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  padding: 8px 16px;
  cursor: pointer;
  min-width: 100px;
  text-align: center;
}
.filters li:last-child {
  margin-right: 0;
}
.filters li.active {
  border-color: #33c68a;
  color: #33c68a;
}
.filters li:hover {
  border-color: #33c68a;
  color: #33c68a;
}
@media all and (max-width: 767px) {
  .filters {
    margin-bottom: 32px;
  }
  .filters li {
    margin-right: 16px;
    margin-bottom: 16px;
  }
}
/*!
// 12. Pricing Tables
// --------------------------------------------------*/
.pricing-1 {
  overflow: visible;
}
.pricing-table-1 {
  padding: 32px !important;
  padding-bottom: 0 !important;
  cursor: pointer;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  position: relative;
}
.pricing-table-1 .pricing-header {
  margin-bottom: 32px;
  overflow: hidden;
}
.pricing-table-1:nth-child(1),
.pricing-table-1:nth-child(1) .pricing-details {
  background: #78dcb4;
}
.pricing-table-1:nth-child(2),
.pricing-table-1:nth-child(2) .pricing-details {
  background: #58d4a1;
}
.pricing-table-1:nth-child(3),
.pricing-table-1:nth-child(3) .pricing-details {
  background: #33c68a;
}
.pricing-table-1 h5 {
  font-size: 22px;
  font-weight: 300;
  margin: 0;
  float: left;
  position: relative;
  top: 22px;
}
.pricing-table-1 .price {
  display: inline-block;
  float: right;
}
.dollar {
  font-style: italic;
  font-size: 18px;
  display: inline-block;
  margin-right: 8px;
  position: relative;
  bottom: 28px;
}
.amount {
  font-size: 64px;
  font-weight: 500;
  line-height: 72px;
}
.pricing-table-1 .alt-font {
  display: block;
  margin: 0;
  font-size: 12px;
  text-align: right;
}
.pricing-details {
  padding-bottom: 0;
  max-height: 0;
  overflow: hidden;
  opacity: 0;
  transition: all 0.3s ease-out;
  -webkit-transition: all 0.3s ease-out;
  -moz-transition: all 0.3s ease-out;
  position: absolute;
  z-index: 10;
  width: 100%;
  left: 0;
  padding: 0 32px 0 32px;
}
.pricing-details ul {
  padding: 24px 0 0 0;
  border-top: 1px solid rgba(255, 255, 255, 0.2);
  border-bottom: 1px solid rgba(255, 255, 255, 0.2);
  margin-bottom: 24px;
}
.pricing-details ul li {
  margin-bottom: 18px;
}
.pricing-details span {
  font-size: 16px;
  position: relative;
  bottom: 6px;
}
.pricing-details ul li i {
  font-size: 28px;
  display: inline-block;
  margin-right: 18px;
}
.pricing-details .text-link {
  margin-right: 24px;
  margin-top: 0;
}
.pricing-table-1:hover .pricing-details {
  max-height: 400px;
  opacity: 1;
  padding-bottom: 32px;
}
@media all and (max-width: 767px) {
  .pricing-details {
    padding-left: 0;
    padding-right: 0;
  }
}
@media all and (max-width: 992px) {
  .pricing-details {
    position: relative;
  }
  .pricing-header br {
    display: block !important;
  }
}
.pricing-table-2 {
  border: 1px solid #ccc;
  padding: 40px 40px 0px 40px;
  text-align: center;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  position: relative;
  cursor: pointer;
}
.pricing-table-2 h2 {
  margin-top: 0;
  letter-spacing: 2px;
  font-weight: 300;
  font-size: 24px;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  margin-right: -2px;
}
.pricing-table-2 ul {
  margin-bottom: 32px;
}
.pricing-table-2 ul li {
  font-size: 18px;
  line-height: 32px;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.pricing-table-2 .action {
  border-top: 1px solid rgba(0, 0, 0, 0);
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  height: 0;
  overflow: hidden;
}
.pricing-table-2 .action span {
  font-size: 12px;
  font-weight: bold;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  margin: 24px 0;
}
.pricing-table-2 span {
  margin: 0;
  font-size: 18px;
  font-weight: normal;
}
.pricing-table-2 .price {
  font-size: 80px;
  margin-bottom: 24px;
  display: inline-block;
  line-height: 96px;
  color: #33c68a;
  font-weight: 300;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.pricing-table-2:hover {
  transform: scale(1.05);
  background: #33c68a;
  z-index: 2;
}
.pricing-table-2:hover h2 {
  color: #fff;
}
.pricing-table-2:hover ul li {
  color: #fff;
}
.pricing-table-2:hover .price {
  color: #fff;
}
.pricing-table-2:hover .action {
  border-color: rgba(255, 255, 255, 0.3);
  height: 75px;
}
.pricing-table-2:hover .action span {
  color: #fff;
}
.pricing-tables-2 div[class*='col-'] {
  padding: 0;
}
.pricing-tables-2 div[class*='col-']:first-child .pricing-table-2 {
  border-right: none;
}
.pricing-tables-2 div[class*='col-']:last-child .pricing-table-2 {
  border-left: none;
}
@media all and (max-width: 767px) {
  .pricing-table-2 {
    margin-bottom: 40px;
  }
  .pricing-tables-2 div[class*='col-']:first-child .pricing-table-2 {
    border-right: 1px solid #ccc;
  }
  .pricing-tables-2 div[class*='col-']:last-child .pricing-table-2 {
    border-left: 1px solid #ccc;
  }
}
/*!
// 13. Social Elements
// --------------------------------------------------*/
.twitter-1 {
  background: #33c68a !important;
}
.twitter-1 i {
  font-size: 48px;
  display: inline-block;
  margin-bottom: 32px;
}
.twitter-1 p {
  color: #fff;
}
.twitter-1 a {
  color: #fff;
  font-weight: 700;
}
.tweets-feed .user {
  display: none;
}
.tweets-feed p {
  font-size: 24px;
  font-weight: 300;
  line-height: 32px;
}
.tweets-feed a {
  color: #fff;
  font-weight: 500;
}
.tweets-feed .timePosted {
  font-size: 14px;
  font-weight: normal;
  font-style: italic;
  opacity: 0.7;
}
.tweets-feed .interact {
  display: none;
}
.twitter-2 i {
  font-size: 80px;
  display: inline-block;
  margin-bottom: 48px;
  opacity: 0.2;
}
.twitter-2 a {
  color: #33c68a;
}
.twitter-2 span a {
  font-weight: 500;
}
.twitter-2 p {
  font-size: 26px;
  line-height: 36px;
}
.instafeed {
  opacity: 0;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.instafeed.fadeIn {
  opacity: 1;
}
.instagram-1 {
  height: 250px;
  overflow: hidden;
}
.instagram-1 li {
  height: 100%;
  width: 16.666667%;
  float: left;
  top: 0;
  opacity: 0.2;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  background-size: cover !important;
}
.instagram-1 li:nth-child(n+7) {
  display: none;
}
.instagram-1 .instafeed {
  position: absolute;
  width: 100%;
  height: 100%;
  top: 0;
}
.instagram-1 ul {
  width: 100%;
  height: 100%;
  position: absolute;
}
.instagram-1 li:hover {
  opacity: 1;
}
.instafeed {
  overflow: hidden;
  width: 100%;
}
.instagram-1 h2 {
  display: inline-block;
  margin-bottom: 0px;
}
.instagram-1 span {
  display: inline-block;
  clear: both;
  float: none;
}
.instagram-1 a {
  color: #333333;
}
.instagram-1 i {
  position: relative;
  margin-right: 6px;
  top: 6px;
}
@media all and (max-width: 1200px) {
  .instagram-1 {
    height: 500px;
  }
  .instagram-1 li {
    height: 50%;
    width: 33.33333%;
  }
}
/*!
// 14. Blog
// --------------------------------------------------*/
.blog-snippets-1 {
  background: #f7f7f7 !important;
  padding-bottom: 40px;
}
.blog-snippet-1 {
  min-height: 360px;
  background: #fff;
  padding: 32px;
  border: 3px solid #fff;
  transition: all 0.2s ease;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
  margin-bottom: 40px;
  overflow: hidden;
  position: relative;
}
.blog-snippet-1 .alt-font {
  font-size: 12px;
  color: #333333;
  margin-top: 0;
}
.blog-snippet-1 h5 {
  color: #33c68a;
}
.blog-snippet-1:hover {
  border-color: #33c68a;
}
.image-snippet p,
.image-snippet h5,
.image-snippet .alt-font,
.image-snippet .text-link {
  color: #fff;
  position: relative;
  z-index: 2;
  border-color: #fff;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.image-snippet:hover {
  border-color: #fff;
}
.image-snippet .background-image-holder {
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.image-snippet:hover .background-image-holder {
  transform: scale(1.05);
}
.image-snippet.overlay:before {
  opacity: 0.4;
}
section:nth-of-type(odd) .blog-snippet-2 .description {
  background: #fff;
}
.blog-snippet-2 {
  overflow: hidden;
  margin-bottom: 80px;
}
.blog-snippet-2 .background-image-holder {
  position: relative;
  height: 450px;
}
.blog-snippet-2 .description {
  padding: 32px;
  background: #f7f7f7;
}
.blog-snippet-2 .meta {
  margin-bottom: 16px;
  padding-bottom: 16px;
  border-bottom: 1px solid #ccc;
}
.blog-snippet-2 .meta span {
  position: relative;
  bottom: 12px;
}
.blog-snippet-2 h3 {
  font-weight: 300;
  color: #33c68a;
  margin-bottom: 16px;
}
.blog-snippet-2 .tag-list {
  display: inline-block;
  margin-left: 24px;
}
.blog-snippet-2 .tag-list li {
  margin-bottom: 0;
}
@media all and (max-width: 767px) {
  .blog-snippets-2 .col-md-8 {
    overflow: hidden;
  }
  .blog-snippet-2 .background-image-holder {
    height: 250px;
  }
  .blog-snippet-2 .tag-list {
    margin-left: 0;
    margin-top: 8px;
  }
  .blog-snippet-2 .tag-list li {
    margin-bottom: 8px;
  }
}
.article-wrapper .avatar {
  display: block;
  margin: 0 auto;
}
.article-wrapper .author-name {
  font-size: 12px;
  color: #333333;
}
.article-single h3 {
  font-size: 16px;
  color: #333333;
  margin-top: 0;
  margin-bottom: 24px;
}
.bullets {
  line-height: 28px;
  margin-bottom: 32px;
}
.bullets li:before {
  width: 7px;
  height: 7px;
  border-radius: 50%;
  background: #333333;
  content: '';
  display: inline-block;
  margin-right: 18px;
}
blockquote {
  font-size: 20px;
  line-height: 36px;
  font-style: italic;
  background: #fff;
  border: none;
  margin: 0 0 32px 0;
  padding: 48px;
}
section:nth-of-type(even) blockquote {
  background: #f7f7f7;
}
.comments-list ol {
  list-style: none;
  padding: 0;
  margin-bottom: 64px;
}
.comments-list h5 {
  margin-bottom: 32px;
}
.comments-list li,
.comments-list .children {
  padding-bottom: 32px;
  border-bottom: 1px solid #ccc;
  margin-bottom: 32px;
}
.comments-list ol li:last-child {
  border-bottom: 0;
  padding-bottom: 0;
  margin-bottom: 0;
}
.blog-comment {
  overflow: hidden;
}
.blog-comment .user,
.blog-comment .info {
  float: left;
  display: inline-block;
}
.blog-comment .user {
  width: 20%;
}
.blog-comment .info {
  width: 80%;
}
.blog-comment .title {
  display: block;
}
.blog-comment .date {
  color: #58d4a1;
  display: inline-block;
  margin-right: 12px;
}
.blog-comment p:first-of-type {
  margin-top: 16px;
}
.blog-comment img {
  max-height: 100px;
}
@media all and (max-width: 767px) {
  .blog-comment .user {
    display: none;
  }
  .blog-comment .info {
    width: 100%;
  }
}
.comments-list .children {
  padding-left: 50px;
}
.comment-form .btn {
  background: none;
}
.comment-form input[type="text"] {
  margin-right: 16px;
  margin-bottom: 16px;
  background: #f7f7f7;
}
.comment-form textarea {
  background: #f7f7f7;
}
.blog-comments:nth-of-type(odd),
.blog-comments:nth-of-type(odd) textarea {
  background: #fff;
}
@media all and (max-width: 990px) {
  .sidebar {
    margin-top: 32px;
  }
}
.widget {
  margin-bottom: 40px;
}
.widget:last-child {
  margin-bottom: 0;
}
.widget .link-list li {
  margin-bottom: 16px;
  padding-bottom: 16px;
  border-bottom: 1px solid #ccc;
}
.widget .link-list li:last-child {
  margin-bottom: 0;
  padding-bottom: 0;
  border-bottom: none;
}
.widget .link-list li a {
  display: block;
  color: #33c68a;
}
.widget .link-list .date {
  font-size: 13px;
}
.widget .search-bar {
  height: 40px;
  position: relative;
}
.widget .search-bar input[type="text"] {
  width: 100%;
  border-bottom: none;
  color: #777;
  opacity: 1;
  left: 0;
  font-size: 14px;
  background: #fff;
  height: 40px;
  padding-left: 8px;
}
.widget .search-bar i {
  color: #33c68a;
  font-size: 26px;
  top: 7px;
  position: absolute;
  right: 32px;
}
section:nth-of-type(even) .widget .search-bar input[type="text"] {
  background: #f7f7f7;
}
.blog-snippets-1 .widget .search-bar input[type="text"] {
  background: #fff !important;
}
.tag-list {
  overflow: hidden;
}
.tag-list li {
  float: left;
  margin-right: 8px;
  margin-bottom: 8px;
}
.tag-list a {
  font-size: 11px;
}
.widget .instafeed ul li {
  width: 33.33333%;
  float: left;
  background-size: cover !important;
}
.widget .instafeed ul li:nth-child(n+7) {
  display: none;
}
.widget .tweet {
  font-size: 14px;
  font-weight: normal;
  line-height: 24px;
}
.widget .tweet a {
  color: #33c68a;
}
/*!
// 15. Shop
// --------------------------------------------------*/
.upper-meta {
  margin-bottom: 64px;
  padding-bottom: 64px;
  border-bottom: 1px solid #ccc;
}
.upper-meta select {
  margin-left: 16px;
  border: none;
  font-size: 12px;
  background: rgba(0, 0, 0, 0.05);
  height: 32px;
  width: 120px;
  border-radius: 0px;
}
@media all and (max-width: 767px) {
  .upper-meta {
    margin-bottom: 40px;
    padding-bottom: 40px;
  }
  .upper-meta .text-right {
    text-align: left;
    margin-top: 12px;
  }
}
.product-container {
  overflow: hidden;
  padding-bottom: 24px;
  border-bottom: 1px solid #ccc;
  margin-bottom: 32px;
}
.product {
  margin-bottom: 40px;
  position: relative;
  overflow: hidden;
}
.product h5 {
  margin-bottom: 0;
  display: inline-block;
}
.product span {
  color: #33c68a;
  font-style: italic;
}
.product .hover-content {
  text-align: center;
  width: 100%;
  height: 100%;
  left: 0;
  margin-left: 0;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.product .btn {
  margin: 0 auto;
  display: inline-block;
}
.product .btn:last-child {
  margin-left: 16px;
}
.product .btn:hover {
  border-color: #fff;
  color: #333333;
}
.product .price {
  float: right;
  font-size: 28px;
  font-weight: 300;
  font-style: normal;
  display: inline-block;
  position: relative;
  bottom: 18px;
}
@media all and (max-width: 767px) {
  .product br {
    display: block;
  }
}
.product-image .background-image-holder {
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.product-image {
  position: relative;
  height: 300px;
  width: 100%;
  margin-bottom: 16px;
  overflow: hidden;
}
.product-image .hover-state {
  position: absolute;
  width: 100%;
  height: 100px;
  bottom: 0;
  top: auto;
  background: #333;
  z-index: 10;
  transform: translate3d(0, 100px, 0);
  -webkit-transform: translate3d(0, 100px, 0);
  -moz-transform: translate3d(0, 100px, 0);
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  opacity: 1;
}
.product-image .hover-content {
  transform: translate3d(0, 0, 0);
  -webkit-transform: translate3d(0, 0, 0);
  -moz-transform: translate3d(0, 0, 0);
  line-height: 100px;
  opacity: 1;
}
.product-image .label,
.image-slider .label {
  position: absolute;
  display: block;
  padding: 8px 16px;
  font-family: 'Montserrat', "Helvetica Neue", Helvetica, Arial, sans-serif;
  text-transform: uppercase;
  font-weight: bold;
  font-size: 12px;
  color: #fff;
  background: #33c68a;
  top: 18px;
  right: 18px;
  z-index: 10;
  border-radius: 0;
  font-style: normal;
}
.product-image:hover .background-image-holder {
  transform: translate3d(0, -100px, 0);
  -webkit-transform: translate3d(0, -100px, 0);
  -moz-transform: translate3d(0, -100px, 0);
}
.product-image:hover .hover-state {
  transform: translate3d(0, 0, 0);
  -webkit-transform: translate3d(0, 0, 0);
  -moz-transform: translate3d(0, 0, 0);
}
.feature-box {
  padding: 80px 0;
}
.feature-box .content {
  padding: 0 48px;
  position: relative;
  z-index: 3;
}
.feature-box h4 {
  margin-bottom: 8px;
}
.feature-box p {
  margin-bottom: 48px;
}
.feature-box .btn-filled:hover {
  border-color: #33c68a;
}
.pagination {
  margin: 0;
}
.pagination > li > a {
  color: #33c68a;
  margin-right: 8px;
  background: none;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.pagination li:last-child a {
  margin-right: 0;
}
.image-slider {
  position: relative;
  width: 100%;
  overflow: hidden;
}
.image-slider .flex-control-nav {
  float: right;
  bottom: 24px;
  text-align: right;
  padding-right: 24px;
}
.image-slider .flex-control-nav li {
  overflow: hidden;
}
.image-slider .flex-control-nav li a {
  background: rgba(0, 0, 0, 0);
  border: 1px solid #333333;
}
.image-slider .flex-control-nav li a.flex-active {
  background: rgba(0, 0, 0, 0.5);
}
.product-single-1 .image-slider .slides li {
  width: 100%;
  height: 500px;
}
.product-single-1 .image-slider .background-image-holder {
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.product-single-1 .image-slider:hover .background-image-holder {
  transform: scale(1.05);
}
@media all and (max-width: 990px) {
  .product-single-1 .image-slider {
    margin-bottom: 32px;
  }
}
@media all and (max-width: 767px) {
  .product-single-1 .image-slider .slides li {
    height: 350px;
  }
}
.product-details {
  overflow: hidden;
  position: relative;
}
.product-details h2 {
  margin-bottom: 8px;
  color: #33c68a;
  padding-bottom: 24px;
  border-bottom: 1px solid #ccc;
  margin-bottom: 24px;
}
.product-details .price {
  float: right;
  font-size: 28px;
  color: #33c68a;
  font-weight: 300;
  position: absolute;
  top: 10px;
  right: 0;
}
.product-details .reviews {
  margin-bottom: 24px;
  width: 100%;
  overflow: hidden;
}
.reviews a {
  line-height: 1;
  color: #58d4a1;
  float: left;
  position: relative;
  top: 3px;
}
.stars {
  overflow: hidden;
  display: inline-block;
  float: left;
  margin-right: 8px;
}
.stars li {
  float: left;
  margin-right: 4px;
  color: #33c68a;
}
section:nth-of-type(odd) .review {
  background: #fff;
}
.cart-preview {
  position: absolute;
  overflow: hidden;
  background: rgba(30, 30, 30, 0.9);
  right: -16px;
  width: 300px;
  max-height: 0;
  transition: all 0.2s ease;
  -webkit-transition: all 0.2s ease;
  -moz-transition: all 0.2s ease;
  opacity: 0;
  transform: scale(0);
}
.cart-preview .product {
  overflow: hidden;
  margin-bottom: 16px;
}
.cart-preview img {
  max-height: 50px;
  display: inline-block;
  margin-right: 16px;
  float: left;
}
.cart-preview .title {
  font-size: 14px;
  color: #fff;
  font-style: normal;
  margin: 0;
}
.cart-preview .price {
  font-size: 12px;
  color: #fff;
  float: none;
  bottom: 0;
  display: block;
}
.cart-preview .description {
  float: left;
}
.cart-preview .controls {
  overflow: hidden;
  padding-top: 24px;
  border-top: 1px solid rgba(255, 255, 255, 0.3);
}
.cart-preview .btn {
  margin: 0 !important;
  top: 0;
  float: left;
  opacity: 1;
}
.cart-preview .btn:last-child {
  float: right;
}
.cart-preview .btn-filled {
  border-color: #33c68a;
}
.nav-functions .cart:hover .cart-preview {
  padding: 24px;
  max-height: 500px;
  opacity: 1;
  transform: scale(1);
}
@media all and (max-width: 990px) {
  .cart-preview {
    display: none;
  }
}
.cart-overview-1:nth-child(odd) .cart-overview-item {
  background: #fff;
}
.cart-overview-1:nth-child(odd) .cart-overview-item:nth-child(even) {
  background: #fafafa;
}
.cart-overview-1:nth-child(even) .cart-overview-item:nth-child(even) {
  background: #fbfbfb;
}
.cart-overview-1 h4 {
  margin-bottom: 40px;
}
.cart-update {
  overflow: hidden;
}
.cart-overview-item {
  overflow: hidden;
  line-height: 60px;
  padding: 16px 32px;
  background: #f7f7f7;
}
.cart-overview-item:last-of-type {
  margin-bottom: 24px;
}
.cart-overview-item .remove-item {
  color: #333333;
  font-size: 20px;
  margin-right: 24px;
  position: relative;
  top: 4px;
}
.cart-overview-item img {
  max-height: 60px;
  display: inline-block;
  margin-right: 24px;
}
.cart-overview-item .title {
  color: #33c68a;
  font-size: 14px;
}
.cart-overview-item .add-to-cart {
  float: right;
  line-height: 60px;
  display: inline-block;
  width: auto;
  position: relative;
  top: 13px;
}
.cart-overview-item .quantity-controls {
  line-height: 40px;
  display: inline-block;
}
.cart-overview-item .price {
  font-size: 20px;
  color: #33c68a;
  float: right;
  display: inline-block;
  font-weight: 300;
  margin-left: 32px;
}
.cart-update input[type="submit"] {
  background: none;
  float: right;
}
@media all and (max-width: 767px) {
  .cart-overview-item .price {
    float: left;
    margin-left: 0;
  }
}
/*!
// 16. Contact
// --------------------------------------------------*/
.contact-method i {
  color: #33c68a;
}
.contact-method .uppercase {
  color: #58d4a1;
  font-size: 14px;
}
.contact-1 .text-block h4 {
  margin-bottom: 24px;
}
.contact-1 .contact-method {
  text-align: center;
  padding-top: 48px;
}
.contact-1 .contact-method i {
  font-size: 80px;
  display: block;
  margin: 0 auto;
  margin-bottom: 24px;
}
.contact-1 .contact-method span {
  display: inline-block;
}
@media all and (max-width: 992px) {
  .contact-1 .text-block p {
    display: none;
  }
  .contact-1 .contact-method {
    text-align: left;
  }
}
.contact-2 .contact-method {
  margin-bottom: 32px;
}
.contact-2 .contact-method i {
  font-size: 40px;
  display: inline-block;
  margin-right: 24px;
}
.contact-2 .contact-method span {
  position: relative;
  bottom: 8px;
  margin: 0;
  display: inline-block;
}
.contact-2 .contact-method:first-child {
  padding-top: 24px;
}
.form-email,
.comment-form {
  overflow: hidden;
}
.form-email input,
.form-email input[type="text"] {
  width: 48%;
  float: left;
  margin-bottom: 15px;
}
.form-email input[type="text"]:nth-child(even) {
  float: right;
}
.form-email textarea,
.comment-form textarea {
  margin-bottom: 15px;
}
.form-email .btn,
.comment-form .btn {
  float: right;
}
@media all and (max-width: 992px) {
  .contact-2 .form-email {
    margin-top: 24px;
  }
}
.project-planner {
  padding: 32px;
  background: #fff;
  overflow: hidden;
}
.project-planner .title {
  font-size: 14px;
  color: #333333;
  display: block;
  margin-bottom: 24px;
}
.project-planner hr {
  height: 1px;
  background: #bbb;
  width: 100%;
  margin: 0 0 32px 0;
}
@media all and (max-width: 767px) {
  .project-planner {
    padding: 0;
    background: none !important;
  }
}
section:nth-of-type(even) .project-planner {
  background: #f7f7f7;
}
.project-planner .options {
  width: 100%;
  overflow: hidden;
  margin-bottom: 12px;
}
.planner-option {
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  border: 2px solid #333333;
  color: #333333;
  width: 31.33333%;
  float: left;
  padding: 8px 12px;
  opacity: 0.4;
  position: relative;
  cursor: pointer;
  margin-bottom: 20px;
  -webkit-touch-callout: none;
  -webkit-user-select: none;
  -khtml-user-select: none;
  -moz-user-select: none;
  -ms-user-select: none;
  user-select: none;
}
.planner-option i {
  font-size: 20px;
  float: right;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  opacity: 0;
}
.planner-option:hover {
  opacity: 1;
}
.planner-option input {
  opacity: 0;
}
.planner-option:nth-child(3n+2) {
  margin: 0 3%;
}
@media all and (max-width: 767px) {
  .planner-option,
  .planner-option:nth-child(3n+2) {
    width: 100%;
    margin: 0;
    margin-bottom: 12px;
  }
}
.planner-option.active {
  border-color: #33c68a;
  color: #33c68a;
  opacity: 1;
}
.planner-option.active i {
  opacity: 1;
}
.planner-option.field-error {
  border: 2px solid #ff0000;
}
.planner-radio {
  display: inline-block;
  margin-right: 24px;
}
.planner-radio input {
  opacity: 0;
  width: 0;
  height: 0;
  overflow: hidden;
}
.planner-radio span {
  font-size: 12px;
}
@media all and (max-width: 767px) {
  .planner-radio {
    width: 50%;
    margin: 0;
    margin-right: 0;
    float: left;
    margin-bottom: 16px;
  }
}
.radio-group {
  margin-bottom: 32px;
  overflow: hidden;
}
.radio-outer,
.radio-inner {
  border-radius: 50%;
  cursor: pointer;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  line-height: 0;
}
.radio-outer {
  width: 25px;
  height: 25px;
  border: 1px solid #333333;
  position: relative;
  text-align: center;
  padding-top: 3px;
}
.radio-inner {
  width: 17px;
  height: 17px;
  background: #333333;
  display: inline-block;
  opacity: 0;
}
.mock-radio {
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  opacity: 0.4;
  margin-bottom: 8px;
}
.mock-radio:hover {
  opacity: 0.5;
}
.mock-radio:hover .radio-inner {
  opacity: 1;
}
.mock-radio.active {
  opacity: 1;
}
.mock-radio.active .radio-outer {
  border-color: #33c68a;
}
.mock-radio.active .radio-inner {
  background: #33c68a;
  opacity: 1;
}
.project-planner input[type="text"] {
  width: 31.333333%;
  margin-bottom: 32px;
}
.project-planner input[type="text"]:nth-child(3n+2) {
  margin: 0 2.5% 32px 2.5%;
}
.project-planner .btn {
  background: none;
  opacity: 1;
}
.project-planner .btn:hover {
  color: #33c68a;
  background: none !important;
}
.project-planner .btn.active {
  opacity: 1;
}
.project-planner .btn.active:hover {
  color: #fff;
  background: #33c68a !important;
}
section:nth-of-type(even) .project-planner {
  background: #fff;
}
section:nth-of-type(odd) .project-planner  {
  background: #f7f7f7;
}
@media all and (max-width: 767px) {
  .project-planner input[type="text"] {
    width: 100%;
    margin-right: 0;
    margin-bottom: 32px;
  }
  .project-planner input[type="text"]:nth-child(3n+2) {
    margin: 0 0 32px 0;
  }
}
.contact-3 {
  padding: 120px 0 80px 0;
}
.contact-3 .overlay:before {
  background: #333333;
  opacity: 0.5;
}
.contact-3 h1 {
  font-weight: 300;
}
.contact-3 .text-block {
  margin-bottom: 64px;
}
.contact-3 i {
  font-size: 64px;
  margin-bottom: 24px;
  display: inline-block;
}
.contact-3 h5 {
  color: #fff;
}
.contact-3 .social-links {
  margin-top: 64px;
}
.contact-3 .social-links li {
  margin: 0 48px 0 0;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  opacity: 0.4;
}
.contact-3 .social-links li:hover {
  opacity: 1;
}
.contact-3 .social-links li:last-child {
  margin: 0 !important;
}
.contact-3 .social-links i {
  color: #fff;
  font-size: 18px;
}
.contact-3 span {
  display: block;
  color: #fff;
  margin-top: 8px;
  opacity: 0.5;
}
@media all and (max-width: 767px) {
  .contact-3 i {
    font-size: 40px;
    margin-bottom: 12px;
  }
}
.contact-4 .instafeed {
  height: 100%;
}
.contact-4 .instafeed ul {
  position: absolute;
  width: 100%;
  height: 100%;
  overflow: hidden;
}
.contact-4 .instafeed li {
  width: 50%;
  float: left;
  height: 50%;
  background-size: cover !important;
  background-position: 50% 50% !important;
}
@media all and (max-width: 1150px) {
  .contact-4 .instafeed li {
    width: 100%;
    height: 50%;
  }
}
.fullwidth-map {
  padding: 0;
  height: 400px;
  overflow: hidden;
  position: relative;
}
.map-holder {
  position: absolute;
  width: 100%;
  height: 150%;
  top: -25%;
  left: 0;
}
.map-holder:before {
  position: absolute;
  content: '';
  width: 100%;
  height: 100%;
  background: none;
  z-index: 1;
}
.disable-overlay:before {
  display: none !important;
  height: 0;
}
.map-holder iframe {
  width: 100%;
  height: 100%;
  position: absolute;
  top: 0;
  left: 0;
}
.disable-map:before {
  width: 0;
  height: 0;
}
.map-holder:before {
  content: '';
  position: absolute;
  width: 100%;
  height: 100%;
  top: 0;
  left: 0;
  z-index: 2;
}
.map-holder.interact:before {
  width: 0;
}
.map-holder.inline {
  height: 400px;
  overflow: hidden;
}
.map-canvas {
  width: 100%;
  height: 100%;
  position: absolute;
  top: 0;
}
@media all and (max-width: 767px) {
  .fullwidth-map {
    height: 350px;
  }
}
/*!
// 17. Form elements
// --------------------------------------------------*/
input.btn-white {
  background: #fff;
  color: #33c68a;
}
input.btn-white:hover {
  background: #33c68a;
  color: #fff;
  border-color: #33c68a;
}

textarea {
  width: 100%;
}
.form-email input[type="submit"].btn {
  background: none;
  min-width: 140px;
}
input[type="submit"] {
  font-weight: 400;
}
input[type="submit"].btn:hover {
  background: #33c68a;
}
input[type="submit"].btn-filled:hover {
  background: #fff;
}
input.success {
  -webkit-box-shadow: inset 1px 1px 5px 2px #54ad28;
  -moz-box-shadow: inset 1px 1px 5px 2px #54ad28;
  box-shadow: inset 1px 1px 5px 2px #54ad28;
}
.field-error {
  -webkit-box-shadow: inset 0px 0px 0px 1px #e82323;
  -moz-box-shadow: inset 0px 0px 0px 1px #e82323;
  box-shadow: inset 0px 0px 0px 1px #e82323;
}

.even-block:nth-of-type(even) {
  background: #f7f7f7;
}
@media all and (max-width: 1200px) {
/*  .image-block .image-holder {
    position: relative;
    width: 100%;
    margin-top: 80px;
  }*/
}
@media (min-width: 990px){
  .row-margin {
    width: 1170px;
    margin-right: auto;
    margin-left: auto;
  }
}
@media only screen and (min-width: 970px) and (max-width: 1200px)  {
  .code-box {
    margin-bottom: 0px;
  }
  .markup {
    margin-top: 10%;
    font-size: 1.5rem;
    line-height: 1.5;
  }
}
/*@media only screen and (min-width: 768px) and (max-width: 992px)  {
  .row-margin {
    width: 90%;
    margin-right: auto;
    margin-left: auto;
  }
  .container {
    width: 90%;
   }
}*/
@media only screen and (max-width: 990px){
  .container {
    width: 100%;
   }
   .row-margin {
    width: 90%;
    margin-right: auto;
    margin-left: auto;
  }
}
.container2{
  width: 100%;
  padding: 12% 0px;
}
.container {
  padding-top: 12%;
  padding-bottom: 12%;
}
.form-success,
.form-error {
  display: none;
  padding: 12px;
  color: #fff;
  background: #39b54a;
  clear: both;
  float: left;
  margin-top: 32px;
  width: 100%;
}
.form-error {
  background: #9e0b0f;
}
.signup-divider .form-success,
.signup-divider .form-error {
  max-width: 70%, margin: 32px auto 0px;
}
.mail-list-form {
  width: 0;
  height: 0;
  opacity: 0;
  position: absolute;
}
.form-loading {
  margin-top: 16px;
  border: 3px solid rgba(0, 0, 0, 0.4);
  border-radius: 30px;
  height: 30px;
  left: 50%;
  margin: -15px 0 0 -15px;
  opacity: 0;
  margin: 28px auto 0px;
  top: 50%;
  width: 30px;
  -webkit-animation: pulsate 1s ease-out;
  -webkit-animation-iteration-count: infinite;
  -moz-animation: pulsate 1s ease-out;
  -moz-animation-iteration-count: infinite;
  animation: pulsate 1s ease-out;
  animation-iteration-count: infinite;
}
@keyframes pulsate {
  0% {
    transform: scale(0.1);
    opacity: 0.0;
  }
  50% {
    opacity: 1;
  }
  100% {
    transform: scale(1.2);
    opacity: 0;
  }
}
@-webkit-keyframes pulsate {
  0% {
    transform: scale(0.1);
    opacity: 0.0;
  }
  50% {
    opacity: 1;
  }
  100% {
    transform: scale(1.2);
    opacity: 0;
  }
}
input[type="submit"][disabled],
input[type="submit"][disabled]:hover {
  border-color: #777;
  color: #777;
}
.signup-divider .form-loading {
  border: 3px solid rgba(255, 255, 255, 0.9);
}
/*!
// 18. Footers
// --------------------------------------------------*/
footer {
  padding: 80px 0;
  background: #fff;
}
footer:nth-child(odd) {
  background: #f7f7f7;
}
.form-newsletter input[type="submit"] {
  background: #33c68a;
  border: none;
  padding: 12px;
  color: #33c68a;
  position: relative;
  right: 5px;
  border: 1px solid #33c68a;
}
.form-newsletter {
  position: relative;
  display: inline-block;
}
.form-newsletter i {
  position: absolute;
  font-size: 48px;
  z-index: 2;
  right: 19px;
  top: 0;
  pointer-events: none;
}
.signup-divider .form-newsletter {
  display: block;
}
.signup-divider .form-newsletter input[type="submit"] {
  color: #fff;
  padding: 19px;
}
.signup-divider .form-newsletter input[type="submit"]:hover {
  color: #33c68a;
}
.footer-1 ul li a {
  color: #333333;
  line-height: 32px;
}
.footer-1 .form-newsletter {
  border: 1px solid #ccc;
  width: 70%;
  float: left;
  min-height: 50px;
}
.footer-1 .form-newsletter input[type="submit"] {
  width: 30%;
  float: right;
}
.footer-1 .footer-lower {
  margin-top: 40px;
  border-top: 1px solid #ccc;
  padding-top: 32px;
}
.footer-1 .footer-lower span {
  color: #888;
}
.footer-1 .footer-lower i {
  margin: 0 8px;
  color: #ff0042;
  font-size: 14px !important;
}
.footer-2 .footer-lower {
  overflow: hidden;
  margin-top: 48px;
}
.footer-2 .copyright {
  opacity: 0.7;
  display: block;
  float: right;
  font-size: 12px;
}
.footer-2 .logo {
  max-height: 40px;
  display: block;
  margin-right: 24px;
  float: left;
  position: relative;
  top: 1px;
}
.footer-2 .tagline {
  display: block;
  float: left;
  line-height: 50px;
}
.footer-3 .logo,
.footer-4 .logo {
  max-height: 30px;
  display: inline-block;
  margin-right: 12px;
}
.footer-3 span {
  opacity: 0.7;
}
.footer-4 .social-links {
  margin-bottom: 80px;
}
.footer-4 .social-links a {
  font-family: 'Montserrat', "Helvetica Neue", Helvetica, Arial, sans-serif;
  text-transform: uppercase;
  font-weight: bold;
  color: #33c68a;
  display: inline-block;
  margin: 24px 0px 16px 0px;
  font-size: 12px;
  color: #333333;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  opacity: 0.5;
}
.footer-4 .social-links li {
  margin-right: 64px;
}
.footer-4 .social-links a:hover {
  opacity: 1;
}
.footer-5 {
  background: #33c68a !important;
  color: #fff;
}
.footer-5 .logo {
  max-height: 60px;
  margin-bottom: 80px;
}
.footer-5 ul {
  overflow: hidden;
  display: inline-block;
}
.footer-5 ul li {
  float: left;
  margin-left: 40px;
}
.footer-5 .text-link {
  font-size: 12px;
  color: #fff;
  border-color: #fff;
  border-bottom: 1px solid #fff;
}
.footer-5 i {
  color: #fff;
}
.footer-5 span {
  font-size: 12px;
  opacity: 0.8;
  position: relative;
  top: 7px;
}
@media all and (max-width: 767px) {
  .footer-5 .logo {
    margin-bottom: 64px;
  }
  .footer-5 ul {
    display: block;
    margin-top: 32px;
  }
  .footer-5 ul li {
    margin-left: 0;
    margin-right: 16px;
  }
}
.footer-6 {
  background: #292929 !important;
  color: rgba(255, 255, 255, 0.8);
}
.footer-6 h5 {
  color: #fff;
  color: rgba(255, 255, 255, 0.9);
}
.footer-6 .tweet {
  font-weight: 400;
  font-size: 14px;
  line-height: 24px;
  margin-bottom: 8px;
}
.footer-6 .tweets-feed a {
  color: #fff;
  color: rgba(255, 255, 255, 0.9);
}
.footer-6 .timePosted {
  margin-bottom: 0;
  font-size: 12px;
  line-height: 18px;
}
.footer-6 .tweets-feed li {
  margin-bottom: 24px;
}
.footer-6 .tweets-feed li:nth-child(n+3) {
  display: none;
}
.footer-6 .link-list a {
  color: #fff;
  opacity: 0.7;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
}
.footer-6 .link-list li {
  margin-bottom: 8px;
}
.footer-6 .link-list a:hover {
  opacity: 1;
  color: #fff;
}
.footer-6 .footer-lower {
  padding-top: 32px;
  border-top: 1px solid #444;
  margin-top: 48px;
  overflow: hidden;
}
.footer-6 .footer-lower span {
  opacity: 0.6;
  font-size: 12px;
}
.footer-6 .footer-lower .social-links {
  float: right;
}
.footer-6 .social-links a {
  font-size: 16px;
  opacity: 0.5;
  transition: all 0.3s ease;
  -webkit-transition: all 0.3s ease;
  -moz-transition: all 0.3s ease;
  color: #fff;
}
.footer-6 .social-links a:hover {
  opacity: 1;
}
.footer-6 .social-links li {
  margin-right: 32px;
}
.footer-6 .social-links li:last-child {
  margin-right: 0;
}
.footer-6 .logo {
  max-height: 30px;
  display: inline-block;
  margin-bottom: 48px;
}
.code-box{
/*  background: #fefefe;*/
/*  border: 1px solid rgba(51,51,51,.1);*/
  margin: 20px 8%;
  position: absolute;
  top: 40%;
  transform: translateY(-50%);
}
@media all and (min-width: 1200px) {
  .markup{
    margin-top:48%;
    background: transparent;
    font-size: 1.6rem;
    line-height: 1.7;
  }
}
@media only screen and (min-width: 970px) and (max-width: 1200px)  {
  .code-box {
    margin-bottom: 0px;
    position: absolute;
    top: 45%;
  }
  .markup {
    margin-top: 10%;
    font-size: 1.5rem;
    line-height: 1.5;
  }

}
.code-tag{
  margin-top: 35px;
  padding: 1.6rem 1.2rem;
  color: #444;
  font-family: Consolas,Monaco,Andale Mono,Ubuntu Mono,monospace;
}
.code-input{
  color: #444;
  padding: 2px;
  margin-left: 5rem;
  display: block;
  clear: both;
}
.code-data{
  color: #999;
  margin-left: 4rem;
  display: block;
  clear: both;
}
@media all and (max-width: 990px) {
  .footer-6 .tweets-feed {
    margin-bottom: 48px;
  }
  .footer-6 .link-list li {
    float: left;
    margin-right: 32px;
  }
  .main-container{
    width: 100%;
  }
}
@media all and (max-width: 767px) {
  .footer-6 div[class*="col-"] {
    margin-bottom: 32px;
  }
  .footer-6 .tweets-feed {
    margin-bottom: 0;
  }
  .footer-6 br {
    display: block;
  }
  .footer-6 .social-links {
    float: left;
    display: block;
    width: 100%;
    margin-top: 24px;
  }
  .footer-2 .tagline {
  padding-top: 10px;
  line-height: 25px;
  }
  .code-box{
  /*background: #fefefe;
  border: 1px solid rgba(51,51,51,.1);
*/
 /* margin: 10px;*/
  position: absolute;
/*  top: 30%;*/
  transform: translateY(-50%);
  font-size: 11px !important;
}
  .markup{
    background: transparent;
    font-size: 1.6rem !important;
  }
  .code-tag{
    /*padding: 1rem;*/
    color: #444;
    font-family: Consolas,Monaco,Andale Mono,Ubuntu Mono,monospace;
  }
  .code-input{
    color: #444;
    margin-left: 3rem;
    display: block;
    clear: both;
  }
  .code-data{
    color: #999;
    margin-left: 2rem;
    display: block;
    clear: both;
  }
}
/*!
// 19. Utility Pages
// --------------------------------------------------*/
.error-page {
  background: #33c68a !important;
  height: 100vh;
}
.error-page i {
  font-size: 620px;
  color: #58d4a1;
  position: absolute;
  opacity: 0.3;
  z-index: -1;
  -moz-animation: float 40s linear infinite alternate;
  -webkit-animation: float 40s linear infinite alternate;
  animation: float 40s linear infinite alternate;
  left: 0;
  top: 100%;
}
.error-page h1 {
  font-weight: 300;
  margin-bottom: 16px;
}
.error-page p {
  margin-bottom: 32px !important;
}
@-webkit-keyframes float {
  0% {
    transform: translate3d(0px, 0px, 0px) rotate(0deg);
  }
  25% {
    transform: translate3d(300px, -200px, 0px) rotate(90deg);
  }
  50% {
    transform: translate3d(500px, -500px, 0px) rotate(180deg);
  }
  75% {
    transform: translate3d(750px, -900px, 0px) rotate(275deg);
  }
  100% {
    transform: translate3d(1100px, -1200px, 0px) rotate(360deg);
  }
}
@-moz-keyframes float {
  0% {
    transform: translate3d(0px, 0px, 0px) rotate(0deg);
  }
  25% {
    transform: translate3d(300px, -200px, 0px) rotate(90deg);
  }
  50% {
    transform: translate3d(500px, -500px, 0px) rotate(180deg);
  }
  75% {
    transform: translate3d(750px, -900px, 0px) rotate(275deg);
  }
  100% {
    transform: translate3d(1100px, -1200px, 0px) rotate(360deg);
  }
}
@keyframes float {
  0% {
    transform: translate3d(0px, 0px, 0px) rotate(0deg);
  }
  25% {
    transform: translate3d(300px, -200px, 0px) rotate(90deg);
  }
  50% {
    transform: translate3d(500px, -500px, 0px) rotate(180deg);
  }
  75% {
    transform: translate3d(750px, -900px, 0px) rotate(275deg);
  }
  100% {
    transform: translate3d(1100px, -1200px, 0px) rotate(360deg);
  }
}
.tooltip-inner {
   min-width: 300px !important;
   max-width: 500px !important;
    padding: 3px 8px;
    color: #999;
    text-align: left !important;
    background-color: #fff !important;
    border-radius: 4px;
    font-size: 14px !important;
}
.code-input-tool {
  margin-left: 1rem;
  color: #444 !important;
  display: block;
  clear: both;
}
.underline{
  text-decoration: underline;
  text-decoration-style: solid;
  display:  inline-table;
  color:#33c68a;
}
.hover_hl{
  background-color: #33c68a;
  color:#fff;
  border-radius: 2px;
  -webkit-animation: fadein 1s; /* Safari, Chrome and Opera > 12.1 */
       -moz-animation: fadein 1s; /* Firefox < 16 */
        -ms-animation: fadein 1s; /* Internet Explorer */
         -o-animation: fadein 1s; /* Opera < 12.1 */
            animation: fadein 1s;
}
#activHover{
  cursor:pointer;
}
.white{
   color:#fff !important;
}
.img_scal{
  padding-bottom: 20px;
  max-width: 190px;
  max-height: 200px;
  vertical-align:middle;
  display: block;
    margin-left: auto;
    margin-right: auto;
}
.img-cloud{
  max-height: 90px;
}
.image-block .box-padding{
   padding:40px !important;
}
.bottom-align{
 /* position: absolute;
  bottom: 2px !important;
  top:58%;*/
}
.text-white a {
    color: #fff;
}
.text-white a:hover {
    color: #33c68a;
}
/*@media (min-width: 768px){
  .container {
      width: 1170px !important;
  }
}*/
@media all and (max-width: 760px) {
  .image-block .text-block{
     padding-right:10%;
  }
}
@media all and (max-width: 990px) {
  .image-block .box-padding {
    padding: 0px !important;
  }
  .hide-code{
    display:none;
  }
}
@media all and (max-width: 1200px) {
  .image-holder h3 {
      font-size: 18px;
  }
}
@media all and (max-width: 1400px) {
  .image-block .text-block {
    padding-left: 10%;
  }
  .main-container {
    width: 100%;
  }
}
@media (min-width: 768px){
  .main-container {
      width: 100% !important;
  }
  .container2 {
    width: 100%;
    padding: 12% 0px;
  }
}
.image-block .text-block{
  padding-right:20%;
}
.footer-2 .container{
   padding-bottom: 0;
   padding-top: 0;
}
.container .row {
    margin-right: 0px !important; 
    margin-left: 0px !important; 
}
connection {
    border: 3px solid;
    color:rgb(51, 198, 138);
     -webkit-animation: fadein 1s; /* Safari, Chrome and Opera > 12.1 */
       -moz-animation: fadein 1s; /* Firefox < 16 */
        -ms-animation: fadein 1s; /* Internet Explorer */
         -o-animation: fadein 1s; /* Opera < 12.1 */
            animation: fadein 1s;
}
@keyframes fadein {
    from { opacity: 0; }
    to   { opacity: 1; }
}

/* Firefox < 16 */
@-moz-keyframes fadein {
    from { opacity: 0; }
    to   { opacity: 1; }
}

/* Safari, Chrome and Opera > 12.1 */
@-webkit-keyframes fadein {
    from { opacity: 0; }
    to   { opacity: 1; }
}

/* Internet Explorer */
@-ms-keyframes fadein {
    from { opacity: 0; }
    to   { opacity: 1; }
}

/* Opera < 12.1 */
@-o-keyframes fadein {
    from { opacity: 0; }
    to   { opacity: 1; }
}
.social-footer{
  padding-top:30px;
}
.green-bg{
   background-color: #33c68a;
   color: #fff !important;
    border-radius: 2px;
    -webkit-animation: fadein 1s;
    -moz-animation: fadein 1s;
    -ms-animation: fadein 1s;
    -o-animation: fadein 1s;
    animation: fadein 1s;
}

