{% extends "base/page.html" %}
{% load crispy_forms_tags %}
{% load my_filters %}
{% load static %}
{% block page_title %}Collection > {{ collection.name }}{% endblock %}
{% block content %}
<div class="row">
    <div class="col">
        <div class="card">
           <div class="card-body">
             {% if collection.workflow_set.count > 0 %}<table id="taskTable" class="tablesorter table table-striped" width="100%">
               <thead>
                    <tr>
                       <th>ID</th>
                       <th>Command</th>
                   </tr>
              </thead>
              <tbody>{% for workflow in collections.workflow_set.all %}
                   <tr>
                      <td>{{ workflow.id }}</td>
                      <td>{{ workflow.command }}</td>
                   </tr>
              {% endfor %}</tbody>
              </table>{% else %}
               <p>You don't have any workflows in this collections. Why don't you <a href="{% url 'main:new_workflow' collection.id %}">create one</a>?</p>{% endif %}
           </div>
        </div>
    </div>
</div>
{% endblock %}
{% block scripts %}
<script>
$(document).ready(function(){
     $("input[type=checkbox]").bootstrapSwitch();
});
</script>
{% endblock %}
